@@ -26,6 +26,7 @@ struct DuplicateImportsRule: SwiftSyntaxCorrectableRule {
         file.duplicateImportsViolationPositions().map { position in
             StyleViolation(
                 ruleDescription: Self.description,
+                severity: configuration.severity,
                 location: Location(file: file, position: position)
             )
         }
@@ -65,11 +66,13 @@ private final class ImportPathVisitor: SyntaxVisitor {
     }
 }
 
+private typealias ByteSourceRange = Range<AbsolutePosition>
+
 private final class IfConfigClauseVisitor: SyntaxVisitor {
     var ifConfigRanges = [ByteSourceRange]()
 
     override func visitPost(_ node: IfConfigClauseSyntax) {
-        ifConfigRanges.append(node.totalByteRange)
+        ifConfigRanges.append(node.range)
     }
 }
 
@@ -78,8 +81,8 @@ private struct ImportPathUsage: Hashable {
         let value: ByteSourceRange
 
         func hash(into hasher: inout Hasher) {
-            hasher.combine(value.offset)
-            hasher.combine(value.length)
+            hasher.combine(value.lowerBound.utf8Offset)
+            hasher.combine(value.length.utf8Length)
         }
     }
 
@@ -93,6 +96,86 @@ private struct ImportPathUsage: Hashable {
     let path: [String]
 }
 
+private let explicitSystemModules = Set([
+    "AddressBook.ABActions",
+    "AddressBook.ABPeoplePicker",
+    "AddressBook.ABPeoplePickerView",
+    "AddressBook.ABPersonPicker",
+    "AddressBook.ABPersonPickerDelegate",
+    "AddressBook.ABPersonView",
+    "AGL.Context",
+    "AGL.GLM",
+    "AGL.Macro",
+    "AGL.Renderers",
+    "AppKit.NSNibConnector",
+    "AppKit.NSNibControlConnector",
+    "AppKit.NSNibOutletConnector",
+    "AudioToolbox.AUCocoaUIView",
+    "AudioToolbox.AudioUnitCarbonView",
+    "AudioToolbox.DefaultAudioOutput",
+    "AudioUnit.AUCocoaUIView",
+    "AudioUnit.AudioUnitCarbonView",
+    "CoreAudio.AudioServerPlugIn",
+    "CoreData.CloudKit",
+    "CoreFoundation.CFPlugInCOM",
+    "CoreImage.CIFilterBuiltins",
+    "CoreMediaIO.CMIOHardwarePlugIn",
+    "CoreMediaIO.CMIOSampleBuffer",
+    "CoreVideo.CVHostTime",
+    "DirectoryService.DirServicesCustom",
+    "ForceFeedback.IOForceFeedbackLib",
+    "Foundation.NSDebug",
+    "GSS.krb5",
+    "IOKit.ata",
+    "IOKit.audio",
+    "IOKit.avc",
+    "IOKit.firewire",
+    "IOKit.graphics",
+    "IOKit.hid",
+    "IOKit.hidsystem",
+    "IOKit.i2c",
+    "IOKit.kext",
+    "IOKit.ndrvsupport",
+    "IOKit.network",
+    "IOKit.ps",
+    "IOKit.pwr_mgt",
+    "IOKit.sbp2",
+    "IOKit.scsi",
+    "IOKit.serial",
+    "IOKit.storage",
+    "IOKit.stream",
+    "IOKit.usb",
+    "IOKit.video",
+    "Kerberos.CredentialsCache2",
+    "Kerberos.locate_plugin",
+    "Kerberos.preauth_plugin",
+    "LDAP.lber",
+    "NetFS.NetFSPlugin",
+    "NetFS.NetFSUtil",
+    "Network.FoundationExtension",
+    "OpenGL.Ext",
+    "OpenGL.GL",
+    "OpenGL.GL3",
+    "OpenGL.GLU",
+    "OpenGL.IOSurface",
+    "OpenGL.Macro",
+    "SceneKit.ModelIO",
+    "Security.AuthorizationPlugin",
+    "Security.AuthSession",
+    "Security.CodeSigning",
+    "Security.eisl",
+    "Security.SecAsn1Coder",
+    "Security.SecAsn1Templates",
+    "Security.SecKey",
+    "Security.SecRandom",
+    "Security.SecureDownload",
+    "Security.SecureTransport",
+    "SecurityFoundation.SFAuthorization",
+    "SystemConfiguration.CaptiveNetwork",
+    "SystemConfiguration.DHCPClientPreferences",
+    "SystemConfiguration.SCDynamicStoreCopyDHCPInfo",
+].map { $0.split(separator: ".").map(String.init) })
+
 private extension SwiftLintFile {
     func duplicateImportsViolationPositions() -> [AbsolutePosition] {
         let importPaths = ImportPathVisitor(viewMode: .sourceAccurate)
@@ -102,8 +185,8 @@ private extension SwiftLintFile {
             .walk(file: self, handler: \.ifConfigRanges)
 
         func ranges(for position: AbsolutePosition) -> [ByteSourceRange] {
-            let positionRange = ByteSourceRange(offset: position.utf8Offset, length: 0)
-            return ifConfigRanges.filter { $0.intersectsOrTouches(positionRange) }
+            let positionRange = position..<(position + SourceLength(utf8Length: 1))
+            return ifConfigRanges.filter { $0.overlapsOrTouches(positionRange) }
         }
 
         var violationPositions = Set<AbsolutePosition>()
@@ -139,7 +222,7 @@ private extension SwiftLintFile {
         }
 
         // Partial matches
-        for `import` in importPaths where !`import`.hasAttributes {
+        for `import` in importPaths where !`import`.hasAttributes && !explicitSystemModules.contains(`import`.path) {
             let path = `import`.path
             let position = `import`.position
             let violation = importPaths.contains { other in
@@ -175,8 +258,7 @@ private extension DuplicateImportsRule {
             if itemsToRemove.isEmpty {
                 return super.visit(node)
             }
-            correctionPositions.append(contentsOf: itemsToRemove.map(\.absolutePosition))
-
+            numberOfCorrections += itemsToRemove.count
             var copy = node
             for indexInParent in itemsToRemove.map(\.indexInParent).reversed() {
                 let currentIndex = copy.index(copy.startIndex, offsetBy: indexInParent)
@@ -187,7 +269,6 @@ private extension DuplicateImportsRule {
                 }
                 copy.remove(at: currentIndex)
             }
-
             return super.visit(copy)
         }
     }
