@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct ExplicitEnumRawValueRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct ExplicitEnumRawValueRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -93,7 +93,7 @@ private extension ExplicitEnumRawValueRule {
 
 private extension SyntaxProtocol {
     func enclosingEnum() -> EnumDeclSyntax? {
-        if let node = self.as(EnumDeclSyntax.self) {
+        if let node = `as`(EnumDeclSyntax.self) {
             return node
         }
 
