@@ -1,8 +1,8 @@
 import SwiftSyntax
 import SwiftSyntaxBuilder
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct ExplicitInitRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct ExplicitInitRule: Rule {
     var configuration = ExplicitInitConfiguration()
 
     static let description = RuleDescription(
@@ -204,11 +204,11 @@ private extension ExplicitInitRule {
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
         override func visit(_ node: FunctionCallExprSyntax) -> ExprSyntax {
             guard let calledExpression = node.calledExpression.as(MemberAccessExprSyntax.self),
-                  let violationPosition = calledExpression.explicitInitPosition,
+                  calledExpression.explicitInitPosition != nil,
                   let calledBase = calledExpression.base else {
                 return super.visit(node)
             }
-            correctionPositions.append(violationPosition)
+            numberOfCorrections += 1
             let newNode = node.with(\.calledExpression, calledBase)
             return super.visit(newNode)
         }
@@ -234,15 +234,15 @@ private extension MemberAccessExprSyntax {
 private extension ExprSyntax {
     /// `String` or `Nested.Type`.
     var isTypeReferenceLike: Bool {
-        if let expr = self.as(DeclReferenceExprSyntax.self), expr.baseName.text.startsWithUppercase {
+        if let expr = `as`(DeclReferenceExprSyntax.self), expr.baseName.text.startsWithUppercase {
             return true
         }
-        if let expr = self.as(MemberAccessExprSyntax.self),
-                  expr.description.split(separator: ".").allSatisfy(\.startsWithUppercase) {
+        if let expr = `as`(MemberAccessExprSyntax.self),
+           expr.description.split(separator: ".").allSatisfy(\.startsWithUppercase) {
             return true
         }
-        if let expr = self.as(GenericSpecializationExprSyntax.self)?.expression.as(DeclReferenceExprSyntax.self),
-                  expr.baseName.text.startsWithUppercase {
+        if let expr = `as`(GenericSpecializationExprSyntax.self)?.expression.as(DeclReferenceExprSyntax.self),
+           expr.baseName.text.startsWithUppercase {
             return true
         }
         return false
