@@ -28,9 +28,9 @@ private let legacyObjcTypes = [
     "NSUUID",
 ]
 
-@SwiftSyntaxRule
-struct LegacyObjcTypeRule: OptInRule {
-    var configuration = SeverityConfiguration<Self>(.warning)
+@SwiftSyntaxRule(optIn: true)
+struct LegacyObjcTypeRule: Rule {
+    var configuration = LegacyObjcTypeConfiguration()
 
     static let description = RuleDescription(
         identifier: "legacy_objc_type",
@@ -44,6 +44,12 @@ struct LegacyObjcTypeRule: OptInRule {
             Example("var className: String = NSStringFromClass(MyClass.self)"),
             Example("_ = URLRequest.CachePolicy.reloadIgnoringLocalCacheData"),
             Example(#"_ = Notification.Name("com.apple.Music.playerInfo")"#),
+            Example(#"""
+            class SLURLRequest: NSURLRequest {
+                let data = NSData()
+                let number: NSNumber
+            }
+            """#, configuration: ["allowed_types": ["NSData", "NSNumber", "NSURLRequest"]]),
         ],
         triggeringExamples: [
             Example("var array = ↓NSArray()"),
@@ -71,25 +77,25 @@ struct LegacyObjcTypeRule: OptInRule {
 private extension LegacyObjcTypeRule {
     final class Visitor: ViolationsSyntaxVisitor<ConfigurationType> {
         override func visitPost(_ node: IdentifierTypeSyntax) {
-            if let typeName = node.typeName, legacyObjcTypes.contains(typeName) {
+            if let name = node.typeName, isViolatingType(name) {
                 violations.append(node.positionAfterSkippingLeadingTrivia)
             }
         }
 
         override func visitPost(_ node: DeclReferenceExprSyntax) {
-            if legacyObjcTypes.contains(node.baseName.text) {
+            if isViolatingType(node.baseName.text) {
                 violations.append(node.baseName.positionAfterSkippingLeadingTrivia)
             }
         }
 
         override func visitPost(_ node: MemberTypeSyntax) {
-            guard node.baseType.as(IdentifierTypeSyntax.self)?.typeName == "Foundation",
-               legacyObjcTypes.contains(node.name.text)
-            else {
-                return
+            if node.baseType.as(IdentifierTypeSyntax.self)?.typeName == "Foundation", isViolatingType(node.name.text) {
+                violations.append(node.name.positionAfterSkippingLeadingTrivia)
             }
+        }
 
-            violations.append(node.name.positionAfterSkippingLeadingTrivia)
+        private func isViolatingType(_ name: String) -> Bool {
+            legacyObjcTypes.contains(name) && !configuration.allowedTypes.contains(name)
         }
     }
 }
