@@ -1,8 +1,9 @@
 import SwiftLintCore
 import SwiftSyntax
+import SwiftSyntaxBuilder
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct NimbleOperatorRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct NimbleOperatorRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -88,9 +89,7 @@ private extension NimbleOperatorRule {
                   let expectedValueExpr = expectation.expectedValueExpr(for: predicate) else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
-
+            numberOfCorrections += 1
             let elements = ExprListSyntax([
                 expectation.baseExpr.with(\.trailingTrivia, .space),
                 operatorExpr.with(\.trailingTrivia, .space),
