@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct NoExtensionAccessModifierRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct NoExtensionAccessModifierRule: Rule {
     var configuration = SeverityConfiguration<Self>(.error)
 
     static let description = RuleDescription(
@@ -12,6 +12,7 @@ struct NoExtensionAccessModifierRule: OptInRule {
         nonTriggeringExamples: [
             Example("extension String {}"),
             Example("\n\n extension String {}"),
+            Example("nonisolated extension String {}"),
         ],
         triggeringExamples: [
             Example("↓private extension String {}"),
@@ -29,8 +30,8 @@ private extension NoExtensionAccessModifierRule {
 
         override func visitPost(_ node: ExtensionDeclSyntax) {
             let modifiers = node.modifiers
-            if modifiers.isNotEmpty {
-                violations.append(modifiers.positionAfterSkippingLeadingTrivia)
+            if let accessLevelModifier = modifiers.accessLevelModifier {
+                violations.append(accessLevelModifier.positionAfterSkippingLeadingTrivia)
             }
         }
     }
