@@ -1,7 +1,11 @@
+// swiftlint:disable file_length
+
+import Foundation
+import SwiftLintCore
 import SwiftSyntax
 
-@SwiftSyntaxRule(foldExpressions: true)
-struct NoMagicNumbersRule: OptInRule {
+@SwiftSyntaxRule(foldExpressions: true, optIn: true)
+struct NoMagicNumbersRule: Rule {
     var configuration = NoMagicNumbersConfiguration()
 
     static let description = RuleDescription(
@@ -81,11 +85,64 @@ struct NoMagicNumbersRule: OptInRule {
             Example("let (lowerBound, upperBound) = (400, 599)"),
             Example("let a = (5, 10)"),
             Example("let notFound = (statusCode: 404, description: \"Not Found\", isError: true)"),
+            Example("#Preview { ContentView(value: 5) }"),
+            Example("@Test func f() { let _ = 2 + 2 }"),
             Example("""
-            #Preview {
-                ContentView(value: 5)
+            @Suite struct Test {
+                @Test func f() {
+                    func g() { let _ = 2 + 2 }
+                    let _ = 2 + 2
+                }
             }
             """),
+            Example("""
+            @Suite actor Test {
+                private var a: Int { 2 }
+                @Test func f() { let _ = 2 + a }
+            }
+            """),
+            Example("""
+            class Test { // @Suite implicitly
+                private var a: Int { 2 }
+                @Test func f() { let _ = 2 + a }
+            }
+            """),
+            Example("""
+            #if compiler(<6.0) && compiler(>4.0)
+            let a = 1
+            #elseif compiler(<3.0)
+            let a = 2
+            #endif
+            """),
+            Example("""
+            let myColor: UIColor = UIColor(red: 0.6, green: 1.0, blue: 0.2, alpha: 0.52)
+            """),
+            Example("""
+            let colorLiteral = #colorLiteral(red: 0.7019607843, green: 0.7019607843, blue: 0.7019607843, alpha: 1)
+            """),
+            Example("""
+            let yourColor: UIColor = UIColor(hue: 0.9, saturation: 0.6, brightness: 0.333334, alpha: 1.0)
+            """, excludeFromDocumentation: true),
+            Example("""
+            let systemColor = UIColor(displayP3Red: 0.3, green: 0.8, blue: 0.5, alpha: 0.75)
+            """, excludeFromDocumentation: true),
+            Example("""
+            func createColor() -> UIColor {
+                return UIColor(white: 0.5, alpha: 0.8)
+            }
+            """, excludeFromDocumentation: true),
+            Example("""
+            let memberColor = UIColor.init(red: 0.5, green: 0.3, blue: 0.9, alpha: 1.0)
+            """, excludeFromDocumentation: true),
+            Example("""
+            func createMemberColor() -> UIColor {
+                return UIColor.init(hue: 0.2, saturation: 0.8, brightness: 0.7, alpha: 0.5)
+            }
+            """, excludeFromDocumentation: true),
+            Example("let a = b + 2", configuration: ["allowed_numbers": [2]], excludeFromDocumentation: true),
+            Example("let a = b + 2", configuration: ["allowed_numbers": [2.0]], excludeFromDocumentation: true),
+            Example("let a = b + 1", configuration: ["allowed_numbers": [2.0]], excludeFromDocumentation: true),
+            Example("let a = b + 2.5", configuration: ["allowed_numbers": [2.5]], excludeFromDocumentation: true),
         ],
         triggeringExamples: [
             Example("foo(↓321)"),
@@ -117,6 +174,16 @@ struct NoMagicNumbersRule: OptInRule {
                 ContentView(value: ↓5)
             }
             """),
+            Example("""
+            #if compiler(<6.0) && compiler(>4.0)
+            f(↓6.0)
+            #elseif compiler(<3.0)
+            f(↓3.0)
+            #else
+            f(↓4.0)
+            #endif
+            """),
+            Example("let a = b + ↓3", configuration: ["allowed_numbers": [2.0]], excludeFromDocumentation: true),
         ]
     )
 }
@@ -127,12 +194,12 @@ private extension NoMagicNumbersRule {
         private var nonTestClasses: Set<String> = []
         private var possibleViolations: [String: Set<AbsolutePosition>] = [:]
 
-        override func visit(_ node: PatternBindingSyntax) -> SyntaxVisitorContinueKind {
-            node.isSimpleTupleAssignment ? .skipChildren : .visitChildren
+        override func visit(_ node: ActorDeclSyntax) -> SyntaxVisitorContinueKind {
+            node.isTestSuite ? .skipChildren : .visitChildren
         }
 
-        override func visit(_ node: MacroExpansionExprSyntax) -> SyntaxVisitorContinueKind {
-            node.macroName.text == "Preview" ? .skipChildren : .visitChildren
+        override func visit(_ node: ClassDeclSyntax) -> SyntaxVisitorContinueKind {
+            node.isTestSuite ? .skipChildren : .visitChildren
         }
 
         override func visitPost(_ node: ClassDeclSyntax) {
@@ -145,20 +212,47 @@ private extension NoMagicNumbersRule {
             }
         }
 
+        override func visit(_ node: EnumDeclSyntax) -> SyntaxVisitorContinueKind {
+            node.isTestSuite ? .skipChildren : .visitChildren
+        }
+
         override func visitPost(_ node: FloatLiteralExprSyntax) {
-            guard node.literal.isMagicNumber else {
+            guard node.literal.isMagicNumber(configuration.allowedNumbers) else {
                 return
             }
             collectViolation(forNode: node)
         }
 
+        override func visit(_ node: FunctionDeclSyntax) -> SyntaxVisitorContinueKind {
+            node.attributes.contains(attributeNamed: "Test") ? .skipChildren : .visitChildren
+        }
+
+        override func visit(_ node: IfConfigClauseSyntax) -> SyntaxVisitorContinueKind {
+            if let elements = node.elements {
+                walk(elements)
+            }
+            return .skipChildren
+        }
+
         override func visitPost(_ node: IntegerLiteralExprSyntax) {
-            guard node.literal.isMagicNumber else {
+            guard node.literal.isMagicNumber(configuration.allowedNumbers) else {
                 return
             }
             collectViolation(forNode: node)
         }
 
+        override func visit(_ node: MacroExpansionExprSyntax) -> SyntaxVisitorContinueKind {
+            node.macroName.text == "Preview" ? .skipChildren : .visitChildren
+        }
+
+        override func visit(_ node: PatternBindingSyntax) -> SyntaxVisitorContinueKind {
+            node.isSimpleTupleAssignment ? .skipChildren : .visitChildren
+        }
+
+        override func visit(_ node: StructDeclSyntax) -> SyntaxVisitorContinueKind {
+            node.isTestSuite ? .skipChildren : .visitChildren
+        }
+
         private func collectViolation(forNode node: some ExprSyntaxProtocol) {
             if node.isMemberOfATestClass(configuration.testParentClasses) {
                 return
@@ -166,6 +260,9 @@ private extension NoMagicNumbersRule {
             if node.isOperandOfFreestandingShiftOperation() {
                 return
             }
+            if node.isPartOfUIColorInitializer() {
+                return
+            }
             let violation = node.positionAfterSkippingLeadingTrivia
             if let extendedTypeName = node.extendedTypeName() {
                 if !testClasses.contains(extendedTypeName) {
@@ -190,12 +287,23 @@ private extension NoMagicNumbersRule {
     }
 }
 
+private extension DeclGroupSyntax {
+    var isTestSuite: Bool {
+        if attributes.contains(attributeNamed: "Suite") {
+            return true
+        }
+        return memberBlock.members.contains {
+            $0.decl.as(FunctionDeclSyntax.self)?.attributes.contains(attributeNamed: "Test") == true
+        }
+    }
+}
+
 private extension TokenSyntax {
-    var isMagicNumber: Bool {
+    func isMagicNumber(_ allowedNumbers: Set<Double>) -> Bool {
         guard let number = Double(text.replacingOccurrences(of: "_", with: "")) else {
             return false
         }
-        if [0, 1, 100].contains(number) {
+        if allowedNumbers.contains(number) {
             return false
         }
         guard let grandparent = parent?.parent else {
@@ -255,6 +363,36 @@ private extension ExprSyntaxProtocol {
         }
         return false
     }
+
+    func isPartOfUIColorInitializer() -> Bool {
+        guard let param = parent?.as(LabeledExprSyntax.self),
+              let label = param.label?.text else {
+            return false
+        }
+        let uiColorInitializerLabels = [
+            "white", "alpha", "red", "displayP3Red", "green", "blue", "hue",
+            "saturation", "brightness", "cgColor", "ciColor", "resource", "patternImage",
+        ]
+        if uiColorInitializerLabels.contains(label),
+           let call = param.parent?.as(LabeledExprListSyntax.self)?.parent?.as(FunctionCallExprSyntax.self) {
+            if let calledExpr = call.calledExpression.as(DeclReferenceExprSyntax.self),
+               calledExpr.baseName.text == "UIColor" {
+                return true
+            }
+            if let memberAccess = call.calledExpression.as(MemberAccessExprSyntax.self),
+               let baseExpr = memberAccess.base?.as(DeclReferenceExprSyntax.self),
+               baseExpr.baseName.text == "UIColor",
+               memberAccess.declName.baseName.text == "init" {
+                return true
+            }
+        }
+        if ["red", "green", "blue", "alpha"].contains(label),
+           let call = param.parent?.as(LabeledExprListSyntax.self)?.parent?.as(MacroExpansionExprSyntax.self),
+           call.macroName.text == "colorLiteral" {
+            return true
+        }
+        return false
+    }
 }
 
 private extension PatternBindingSyntax {
