@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct ObjectLiteralRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct ObjectLiteralRule: Rule {
     var configuration = ObjectLiteralConfiguration<Self>()
 
     static let description = RuleDescription(
@@ -62,8 +62,8 @@ private extension ObjectLiteralRule {
         private func isColorInit(node: FunctionCallExprSyntax, name: String) -> Bool {
             guard inits(forClasses: ["UIColor", "NSColor"]).contains(name),
                   case let argumentsNames = node.arguments.compactMap(\.label?.text),
-                argumentsNames == ["red", "green", "blue", "alpha"] || argumentsNames == ["white", "alpha"] else {
-                    return false
+                  argumentsNames == ["red", "green", "blue", "alpha"] || argumentsNames == ["white", "alpha"] else {
+                return false
             }
 
             return node.arguments.allSatisfy(\.expression.canBeExpressedAsColorLiteralParams)
@@ -88,13 +88,13 @@ private extension StringLiteralExprSyntax {
 
 private extension ExprSyntax {
     var canBeExpressedAsColorLiteralParams: Bool {
-        if self.is(FloatLiteralExprSyntax.self) ||
-            self.is(IntegerLiteralExprSyntax.self) ||
-            self.is(BinaryOperatorExprSyntax.self) {
+        if `is`(FloatLiteralExprSyntax.self) ||
+            `is`(IntegerLiteralExprSyntax.self) ||
+            `is`(BinaryOperatorExprSyntax.self) {
             return true
         }
 
-        if let expr = self.as(SequenceExprSyntax.self) {
+        if let expr = `as`(SequenceExprSyntax.self) {
             return expr.elements.allSatisfy(\.canBeExpressedAsColorLiteralParams)
         }
 
