@@ -1,7 +1,8 @@
 import SwiftSyntax
+import SwiftSyntaxBuilder
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct PreferZeroOverExplicitInitRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct PreferZeroOverExplicitInitRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -50,16 +51,12 @@ private extension PreferZeroOverExplicitInitRule {
             guard node.hasViolation, let name = node.name else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
-
+            numberOfCorrections += 1
             let newNode = MemberAccessExprSyntax(name: "zero")
                 .with(\.base, "\(raw: name)")
-            return super.visit(
-                newNode
-                    .with(\.leadingTrivia, node.leadingTrivia)
-                    .with(\.trailingTrivia, node.trailingTrivia)
-            )
+                .with(\.leadingTrivia, node.leadingTrivia)
+                .with(\.trailingTrivia, node.trailingTrivia)
+            return super.visit(newNode)
         }
     }
 }
