@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct RedundantNilCoalescingRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct RedundantNilCoalescingRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -44,9 +44,8 @@ private extension RedundantNilCoalescingRule {
             else {
                 return super.visit(node)
             }
-
+            numberOfCorrections += 1
             let newNode = ExprListSyntax(node.dropLast(2)).with(\.trailingTrivia, [])
-            correctionPositions.append(secondToLastExpression.operator.positionAfterSkippingLeadingTrivia)
             return super.visit(newNode)
         }
     }
