@@ -1,4 +1,5 @@
 import Foundation
+import SourceKittenFramework
 import SwiftSyntax
 
 private let attributeNamesImplyingObjc: Set<String> = [
@@ -59,21 +60,21 @@ private extension AttributeListSyntax {
 
 private extension Syntax {
     var isFunctionOrStoredProperty: Bool {
-        if self.is(FunctionDeclSyntax.self) {
+        if `is`(FunctionDeclSyntax.self) {
             return true
         }
-        if let variableDecl = self.as(VariableDeclSyntax.self),
-                  variableDecl.bindings.allSatisfy({ $0.accessorBlock == nil }) {
+        if let variableDecl = `as`(VariableDeclSyntax.self),
+           variableDecl.bindings.allSatisfy({ $0.accessorBlock == nil }) {
             return true
         }
         return false
     }
 
     var functionOrVariableModifiers: DeclModifierListSyntax? {
-        if let functionDecl = self.as(FunctionDeclSyntax.self) {
+        if let functionDecl = `as`(FunctionDeclSyntax.self) {
             return functionDecl.modifiers
         }
-        if let variableDecl = self.as(VariableDeclSyntax.self) {
+        if let variableDecl = `as`(VariableDeclSyntax.self) {
             return variableDecl.modifiers
         }
         return nil
@@ -93,12 +94,12 @@ private extension AttributeListSyntax {
             return nil
         }
         if parent?.isFunctionOrStoredProperty == true,
-                  let parentClassDecl = parent?.parent?.parent?.parent?.parent?.as(ClassDeclSyntax.self),
-                  parentClassDecl.attributes.contains(attributeNamed: "objcMembers") {
+           let parentClassDecl = parent?.parent?.parent?.parent?.parent?.as(ClassDeclSyntax.self),
+           parentClassDecl.attributes.contains(attributeNamed: "objcMembers") {
             return parent?.functionOrVariableModifiers?.containsPrivateOrFileprivate() == true ? nil : objcAttribute
         }
         if let parentExtensionDecl = parent?.parent?.parent?.parent?.parent?.as(ExtensionDeclSyntax.self),
-                  parentExtensionDecl.attributes.objCAttribute != nil {
+           parentExtensionDecl.attributes.objCAttribute != nil {
             return objcAttribute
         }
         return nil
@@ -111,7 +112,7 @@ extension RedundantObjcAttributeRule {
         let nsCharSet = CharacterSet.whitespacesAndNewlines.bridge()
         let nsContent = file.contents.bridge()
         while nsCharSet
-            .characterIsMember(nsContent.character(at: violationRange.upperBound + whitespaceAndNewlineOffset)) {
+                .characterIsMember(nsContent.character(at: violationRange.upperBound + whitespaceAndNewlineOffset)) {
             whitespaceAndNewlineOffset += 1
         }
 
