@@ -73,7 +73,7 @@ struct RedundantVoidReturnRule: Rule {
 private extension RedundantVoidReturnRule {
     final class Visitor: ViolationsSyntaxVisitor<ConfigurationType> {
         override func visitPost(_ node: ReturnClauseSyntax) {
-            if !configuration.includeClosures && node.parent?.is(ClosureSignatureSyntax.self) == true {
+            if !configuration.includeClosures, node.parent?.is(ClosureSignatureSyntax.self) == true {
                 return
             }
 
@@ -88,25 +88,23 @@ private extension RedundantVoidReturnRule {
         override func visit(_ node: ClosureSignatureSyntax) -> ClosureSignatureSyntax {
             guard configuration.includeClosures,
                   let output = node.returnClause,
-                  let tokenBeforeOutput = output.previousToken(viewMode: .sourceAccurate),
+                  output.previousToken(viewMode: .sourceAccurate) != nil,
                   output.containsRedundantVoidViolation
             else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(tokenBeforeOutput.endPositionBeforeTrailingTrivia)
+            numberOfCorrections += 1
             return super.visit(node.with(\.returnClause, nil).removingTrailingSpaceIfNeeded())
         }
 
         override func visit(_ node: FunctionSignatureSyntax) -> FunctionSignatureSyntax {
             guard let output = node.returnClause,
-                  let tokenBeforeOutput = output.previousToken(viewMode: .sourceAccurate),
+                  output.previousToken(viewMode: .sourceAccurate) != nil,
                   output.containsRedundantVoidViolation
             else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(tokenBeforeOutput.endPositionBeforeTrailingTrivia)
+            numberOfCorrections += 1
             return super.visit(node.with(\.returnClause, nil).removingTrailingSpaceIfNeeded())
         }
     }
@@ -118,7 +116,7 @@ private extension ReturnClauseSyntax {
             return false
         }
         if let simpleReturnType = type.as(IdentifierTypeSyntax.self) {
-           return simpleReturnType.typeName == "Void"
+            return simpleReturnType.typeName == "Void"
         }
         if let tupleReturnType = type.as(TupleTypeSyntax.self) {
             return tupleReturnType.elements.isEmpty
