@@ -1,7 +1,8 @@
+import SwiftBasicFormat
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct ReturnValueFromVoidFunctionRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct ReturnValueFromVoidFunctionRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -33,7 +34,7 @@ private extension ReturnValueFromVoidFunctionRule {
                   Syntax(statements).enclosingFunction()?.returnsVoid == true else {
                 return super.visit(statements)
             }
-            correctionPositions.append(returnStmt.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let newStmtList = Array(statements.dropLast()) + [
                 CodeBlockItemSyntax(item: .expr(expr))
                     .with(\.leadingTrivia, returnStmt.leadingTrivia),
@@ -53,11 +54,11 @@ private extension ReturnValueFromVoidFunctionRule {
 
 private extension Syntax {
     func enclosingFunction() -> FunctionDeclSyntax? {
-        if let node = self.as(FunctionDeclSyntax.self) {
+        if let node = `as`(FunctionDeclSyntax.self) {
             return node
         }
 
-        if self.is(ClosureExprSyntax.self) || self.is(VariableDeclSyntax.self) || self.is(InitializerDeclSyntax.self) {
+        if `is`(ClosureExprSyntax.self) || `is`(VariableDeclSyntax.self) || `is`(InitializerDeclSyntax.self) {
             return nil
         }
 
