@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct ShorthandOptionalBindingRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct ShorthandOptionalBindingRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -95,8 +95,7 @@ private extension ShorthandOptionalBindingRule {
             guard node.isShadowingOptionalBinding else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let newNode = node
                 .with(\.initializer, nil)
                 .with(\.pattern, node.pattern.with(\.trailingTrivia, node.trailingTrivia))
