@@ -1,3 +1,4 @@
+import SwiftBasicFormat
 import SwiftSyntax
 
 private func embedInSwitch(
@@ -50,9 +51,9 @@ struct UnneededBreakInSwitchRule: Rule {
         ],
         corrections: [
             embedInSwitch("something()\n    ↓break")
-            : embedInSwitch("something()"),
+                : embedInSwitch("something()"),
             embedInSwitch("something()\n    ↓break // line comment")
-            : embedInSwitch("something()\n     // line comment"),
+                : embedInSwitch("something()\n     // line comment"),
             embedInSwitch("""
                 something()
                 ↓break
@@ -60,14 +61,14 @@ struct UnneededBreakInSwitchRule: Rule {
                 block comment
                 */
                 """)
-            : embedInSwitch("""
+                : embedInSwitch("""
                 something()
                 /*
                 block comment
                 */
                 """),
             embedInSwitch("something()\n    ↓break /// doc line comment")
-            : embedInSwitch("something()\n     /// doc line comment"),
+                : embedInSwitch("something()\n     /// doc line comment"),
             embedInSwitch("""
                 something()
                 ↓break
@@ -75,16 +76,16 @@ struct UnneededBreakInSwitchRule: Rule {
                 /// doc block comment
                 ///
                 """)
-            : embedInSwitch("""
+                : embedInSwitch("""
                 something()
                 ///
                 /// doc block comment
                 ///
                 """),
             embedInSwitch("something()\n    ↓break", case: "default")
-            : embedInSwitch("something()", case: "default"),
+                : embedInSwitch("something()", case: "default"),
             embedInSwitch("something()\n    ↓break", case: "case .foo, .foo2 where condition")
-            : embedInSwitch("something()", case: "case .foo, .foo2 where condition"),
+                : embedInSwitch("something()", case: "case .foo, .foo2 where condition"),
         ]
     )
 }
@@ -95,7 +96,6 @@ private extension UnneededBreakInSwitchRule {
             guard let statement = node.unneededBreak else {
                 return
             }
-
             violations.append(statement.item.positionAfterSkippingLeadingTrivia)
         }
     }
@@ -103,22 +103,17 @@ private extension UnneededBreakInSwitchRule {
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
         override func visit(_ node: SwitchCaseSyntax) -> SwitchCaseSyntax {
             let stmts = CodeBlockItemListSyntax(node.statements.dropLast())
-
             guard let breakStatement = node.unneededBreak, let secondLast = stmts.last else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(breakStatement.item.positionAfterSkippingLeadingTrivia)
-
+            numberOfCorrections += 1
             let trivia = breakStatement.item.leadingTrivia + breakStatement.item.trailingTrivia
-
             let newNode = node
                 .with(\.statements, stmts)
                 .with(\.statements.trailingTrivia, secondLast.item.trailingTrivia + trivia)
                 .trimmed { !$0.isComment }
                 .formatted()
                 .as(SwitchCaseSyntax.self)!
-
             return super.visit(newNode)
         }
     }
@@ -131,7 +126,6 @@ private extension SwitchCaseSyntax {
               breakStatement.label == nil else {
             return nil
         }
-
         return statements.last
     }
 }
