@@ -11,7 +11,9 @@
 // See https://swift.org/CONTRIBUTORS.txt for the list of Swift project authors
 //
 
+import Foundation
 import SwiftSyntax
+import SwiftSyntaxBuilder
 
 @SwiftSyntaxRule(explicitRewriter: true)
 struct UnneededSynthesizedInitializerRule: Rule {
@@ -60,7 +62,7 @@ private extension UnneededSynthesizedInitializerRule {
 
         override func visit(_ node: InitializerDeclSyntax) -> DeclSyntax {
             if unneededInitializers.contains(node) {
-                correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+                numberOfCorrections += 1
                 let expr: DeclSyntax = ""
                 return expr
                     .with(\.leadingTrivia, node.leadingTrivia)
