@@ -1,14 +1,24 @@
 import SwiftOperators
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct XCTSpecificMatcherRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct XCTSpecificMatcherRule: Rule {
     var configuration = XCTSpecificMatcherConfiguration()
 
     static let description = RuleDescription(
         identifier: "xct_specific_matcher",
         name: "XCTest Specific Matcher",
-        description: "Prefer specific XCTest matchers over `XCTAssertEqual` and `XCTAssertNotEqual`.",
+        description: "Prefer specific XCTest matchers.",
+        rationale: """
+        Using specific matchers like `XCTAssertEqual`, `XCTAssertNotEqual`, `XCTAssertTrue`, `XCTAssertFalse`,
+        `XCTAssertIdentical` and `XCTAssertNotIdentical` improves code readability and clarity. They more clearly
+        state the intention of the assertion.
+
+        Consider for example `XCTAssertTrue(foo == bar)`, which requires two details to grasp: that `foo` and `bar`
+        are equal, and that the result of the comparison shall be true. Using `XCTAssertEqual(foo, bar)` makes it
+        clear that the intention is to check equality, without needing to understand the underlying logic of the
+        comparison.
+        """,
         kind: .idiomatic,
         nonTriggeringExamples: XCTSpecificMatcherRuleExamples.nonTriggeringExamples,
         triggeringExamples: XCTSpecificMatcherRuleExamples.triggeringExamples
@@ -25,7 +35,7 @@ private extension XCTSpecificMatcherRule {
                     reason: "Prefer the specific matcher '\(suggestion)' instead"
                 ))
             } else if configuration.matchers.contains(.oneArgumentAsserts),
-               let suggestion = OneArgXCTAssert.violations(in: node) {
+                      let suggestion = OneArgXCTAssert.violations(in: node) {
                 violations.append(ReasonedRuleViolation(
                     position: node.positionAfterSkippingLeadingTrivia,
                     reason: "Prefer the specific matcher '\(suggestion)' instead"
@@ -43,16 +53,25 @@ private enum OneArgXCTAssert: String {
     private enum Comparison: String {
         case equal = "=="
         case unequal = "!="
+        case identical = "==="
+        case notIdentical = "!=="
     }
 
+    // swiftlint:disable:next cyclomatic_complexity
     private func suggestion(for comparisonOperator: Comparison) -> String {
         switch (self, comparisonOperator) {
-        case (.assert, .equal):  return "XCTAssertEqual"
-        case (.true, .equal):  return "XCTAssertEqual"
-        case (.assert, .unequal):  return "XCTAssertNotEqual"
-        case (.true, .unequal):  return "XCTAssertNotEqual"
-        case (.false, .equal):  return "XCTAssertNotEqual"
-        case (.false, .unequal):  return "XCTAssertEqual"
+        case (.assert, .equal): "XCTAssertEqual"
+        case (.true, .equal): "XCTAssertEqual"
+        case (.assert, .unequal): "XCTAssertNotEqual"
+        case (.true, .unequal): "XCTAssertNotEqual"
+        case (.false, .equal): "XCTAssertNotEqual"
+        case (.false, .unequal): "XCTAssertEqual"
+        case (.assert, .identical): "XCTAssertIdentical"
+        case (.true, .identical): "XCTAssertIdentical"
+        case (.assert, .notIdentical): "XCTAssertNotIdentical"
+        case (.true, .notIdentical): "XCTAssertNotIdentical"
+        case (.false, .identical): "XCTAssertNotIdentical"
+        case (.false, .notIdentical): "XCTAssertIdentical"
         }
     }
 
