@@ -1,13 +1,44 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct ArrayInitRule: OptInRule, @unchecked Sendable {
+@SwiftSyntaxRule(optIn: true)
+struct ArrayInitRule: Rule, @unchecked Sendable {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
         identifier: "array_init",
         name: "Array Init",
         description: "Prefer using `Array(seq)` over `seq.map { $0 }` to convert a sequence into an Array",
+        rationale: """
+        When converting the elements of a sequence directly into an `Array`, for clarity, prefer using the `Array` \
+        constructor over calling `map`. For example
+
+        ```
+        Array(foo)
+        ```
+
+        rather than
+
+        ```
+        foo.↓map({ $0 })
+        ```
+
+        If some processing of the elements is required, then using `map` is fine. For example
+
+        ```
+        foo.map { !$0 }
+        ```
+
+        Constructs like
+
+        ```
+        enum MyError: Error {}
+        let myResult: Result<String, MyError> = .success("")
+        let result: Result<Any, MyError> = myResult.map { $0 }
+        ```
+
+        may be picked up as false positives by the `array_init` rule. If your codebase contains constructs like this, \
+        consider using the `typesafe_array_init` analyzer rule instead.
+        """,
         kind: .lint,
         nonTriggeringExamples: [
             Example("Array(foo)"),
@@ -100,7 +131,7 @@ private extension ClosureSignatureSyntax {
             return list.onlyElement?.name.text
         }
         if let clause = parameterClause?.as(ClosureParameterClauseSyntax.self), clause.parameters.count == 1,
-                  clause.parameters.first?.secondName == nil {
+           clause.parameters.first?.secondName == nil {
             return clause.parameters.first?.firstName.text
         }
         return nil
