@@ -8,6 +8,24 @@ struct ClassDelegateProtocolRule: Rule {
         identifier: "class_delegate_protocol",
         name: "Class Delegate Protocol",
         description: "Delegate protocols should be class-only so they can be weakly referenced",
+        rationale: """
+        Delegate protocols are usually `weak` to avoid retain cycles, or bad references to deallocated delegates.
+
+        The `weak` operator is only supported for classes, and so this rule enforces that protocols ending in \
+        "Delegate" are class based.
+
+        For example
+
+        ```
+        protocol FooDelegate: class {}
+        ```
+
+        versus
+
+        ```
+        ↓protocol FooDelegate {}
+        ```
+        """,
         kind: .lint,
         nonTriggeringExamples: [
             Example("protocol FooDelegate: class {}"),
@@ -18,15 +36,23 @@ struct ClassDelegateProtocolRule: Rule {
             Example("@objc(MyFooDelegate)\n protocol FooDelegate {}"),
             Example("protocol FooDelegate: BarDelegate {}"),
             Example("protocol FooDelegate: AnyObject {}"),
+            Example("protocol FooDelegate: AnyObject & Foo {}"),
+            Example("protocol FooDelegate: Foo, AnyObject & Foo {}"),
+            Example("protocol FooDelegate: Foo & AnyObject & Bar {}"),
             Example("protocol FooDelegate: NSObjectProtocol {}"),
             Example("protocol FooDelegate where Self: BarDelegate {}"),
+            Example("protocol FooDelegate where Self: BarDelegate & Bar {}"),
+            Example("protocol FooDelegate where Self: Foo & BarDelegate & Bar {}"),
             Example("protocol FooDelegate where Self: AnyObject {}"),
             Example("protocol FooDelegate where Self: NSObjectProtocol {}"),
+            Example("protocol FooDelegate: Actor {}"),
         ],
         triggeringExamples: [
             Example("↓protocol FooDelegate {}"),
             Example("↓protocol FooDelegate: Bar {}"),
+            Example("↓protocol FooDelegate: Foo & Bar {}"),
             Example("↓protocol FooDelegate where Self: StringProtocol {}"),
+            Example("↓protocol FooDelegate where Self: A & B {}"),
         ]
     )
 }
@@ -38,10 +64,10 @@ private extension ClassDelegateProtocolRule {
         }
 
         override func visitPost(_ node: ProtocolDeclSyntax) {
-            if node.name.text.hasSuffix("Delegate") &&
-                !node.hasObjCAttribute() &&
-                !node.isClassRestricted() &&
-                !node.inheritsFromObjectOrDelegate() {
+            if node.name.text.hasSuffix("Delegate"),
+               !node.hasObjCAttribute(),
+               !node.isClassRestricted(),
+               !node.inheritsFromObjectOrDelegate() {
                 violations.append(node.protocolKeyword.positionAfterSkippingLeadingTrivia)
             }
         }
@@ -81,10 +107,13 @@ private extension ProtocolDeclSyntax {
 
 private extension TypeSyntax {
     func isObjectOrDelegate() -> Bool {
-        guard let typeName = self.as(IdentifierTypeSyntax.self)?.typeName else {
-            return false
+        if let typeName = `as`(IdentifierTypeSyntax.self)?.typeName {
+            let objectTypes = ["AnyObject", "NSObjectProtocol", "Actor"]
+            return objectTypes.contains(typeName) || typeName.hasSuffix("Delegate")
         }
-
-        return typeName == "AnyObject" || typeName == "NSObjectProtocol" || typeName.hasSuffix("Delegate")
+        if let combined = `as`(CompositionTypeSyntax.self) {
+            return combined.elements.contains { $0.type.isObjectOrDelegate() }
+        }
+        return false
     }
 }
