@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct LowerACLThanParentRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct LowerACLThanParentRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -96,8 +96,7 @@ private extension LowerACLThanParentRule {
             guard node.isHigherACLThanParent else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let newNode: DeclModifierSyntax
             if node.name.tokenKind == .keyword(.open) {
                 newNode = DeclModifierSyntax(
@@ -167,14 +166,14 @@ private extension SyntaxProtocol {
 
 private extension Syntax {
     var isNominalTypeDecl: Bool {
-        self.is(StructDeclSyntax.self) ||
-            self.is(ClassDeclSyntax.self) ||
-            self.is(ActorDeclSyntax.self) ||
-            self.is(EnumDeclSyntax.self)
+        `is`(StructDeclSyntax.self) ||
+            `is`(ClassDeclSyntax.self) ||
+            `is`(ActorDeclSyntax.self) ||
+            `is`(EnumDeclSyntax.self)
     }
 
     var isExtensionDecl: Bool {
-        self.is(ExtensionDeclSyntax.self)
+        `is`(ExtensionDeclSyntax.self)
     }
 
     var modifiers: DeclModifierListSyntax? {
