@@ -2,7 +2,7 @@ import Foundation
 import SwiftSyntax
 
 @SwiftSyntaxRule(explicitRewriter: true)
-struct MarkRule: CorrectableRule {
+struct MarkRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -29,9 +29,7 @@ private extension MarkRule {
         override func visit(_ token: TokenSyntax) -> TokenSyntax {
             var pieces = token.leadingTrivia.pieces
             for result in token.violationResults() {
-                // caution: `correctionPositions` records the positions before the mutations.
-                // https://github.com/realm/SwiftLint/pull/4297
-                correctionPositions.append(result.position)
+                numberOfCorrections += 1
                 result.correct(&pieces)
             }
             return super.visit(token.with(\.leadingTrivia, Trivia(pieces: pieces)))
@@ -80,7 +78,6 @@ private extension TokenSyntax {
         ].map(basePattern).joined(separator: "|")) + capturingGroup(hyphenOrEmpty)
 
         private static let anySpace = " *"
-        private static let nonSpaceOrTwoOrMoreSpace = "(?: {2,})?"
 
         private static let anyText = "(?:\\S.*)"
 
