@@ -78,7 +78,7 @@ private extension OrphanedDocCommentRule {
                 switch piece {
                 case .docLineComment(let comment), .docBlockComment(let comment):
                     // These patterns are often used for "file header" style comments
-                    if !comment.hasPrefix("////") && !comment.hasPrefix("/***") {
+                    if !comment.hasPrefix("////"), !comment.hasPrefix("/***") {
                         if isOrphanedDocComment(with: &iterator) {
                             let utf8Length = pieces[..<index].reduce(0) { $0 + $1.sourceLength.utf8Length }
                             violations.append(node.position.advanced(by: utf8Length))
@@ -99,7 +99,7 @@ private func isOrphanedDocComment(
     while let (_, piece) = iterator.next() {
         switch piece {
         case .docLineComment, .docBlockComment,
-                .carriageReturns, .carriageReturnLineFeeds, .newlines, .spaces:
+             .carriageReturns, .carriageReturnLineFeeds, .newlines, .spaces:
             break
 
         case .lineComment, .blockComment:
