@@ -26,6 +26,13 @@ struct OverrideInExtensionRule: OptInRule, SwiftSyntaxRule {
                 override var description: String { return "" }
             }
             """),
+            Example("""
+            @objc
+            @implementation
+            extension Person {
+                override func celebrateBirthday() {}
+            }
+            """),
         ],
         triggeringExamples: [
             Example("extension Person {\n  override ↓var age: Int { return 42 }\n}"),
@@ -77,6 +84,11 @@ private extension OverrideInExtensionRule {
                 return .skipChildren
             }
 
+            // `@objc @implementation` methods may often use `override`.
+            if node.attributes.contains(attributeNamed: "implementation") {
+                return .skipChildren
+            }
+
             return .visitChildren
         }
     }
