@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct PrivateOutletRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct PrivateOutletRule: Rule {
     var configuration = PrivateOutletConfiguration()
 
     static let description = RuleDescription(
@@ -89,7 +89,7 @@ private extension PrivateOutletRule {
                 return
             }
 
-            if configuration.allowPrivateSet && decl.modifiers.containsPrivateOrFileprivate(setOnly: true) {
+            if configuration.allowPrivateSet, decl.modifiers.containsPrivateOrFileprivate(setOnly: true) {
                 return
             }
 
