@@ -132,11 +132,11 @@ private extension PrivateUnitTestRule {
         override var skippableDeclarations: [any DeclSyntaxProtocol.Type] { .all }
 
         override func visit(_ node: ClassDeclSyntax) -> SyntaxVisitorContinueKind {
-            !node.isPrivate && node.hasParent(configuredIn: configuration) ? .visitChildren : .skipChildren
+            !node.isPrivate && node.isXCTestCase(configuration.testParentClasses) ? .visitChildren : .skipChildren
         }
 
         override func visitPost(_ node: ClassDeclSyntax) {
-            if node.isPrivate, node.hasParent(configuredIn: configuration) {
+            if node.isPrivate, node.isXCTestCase(configuration.testParentClasses) {
                 violations.append(node.classKeyword.positionAfterSkippingLeadingTrivia)
             }
         }
@@ -150,11 +150,10 @@ private extension PrivateUnitTestRule {
 
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
         override func visit(_ node: ClassDeclSyntax) -> DeclSyntax {
-            guard node.isPrivate, node.hasParent(configuredIn: configuration) else {
+            guard node.isPrivate, node.isXCTestCase(configuration.testParentClasses) else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let (modifiers, declKeyword) = withoutPrivate(modifiers: node.modifiers, declKeyword: node.classKeyword)
             return super.visit(node.with(\.modifiers, modifiers).with(\.classKeyword, declKeyword))
         }
@@ -163,8 +162,7 @@ private extension PrivateUnitTestRule {
             guard node.isTestMethod, node.isPrivate else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let (modifiers, declKeyword) = withoutPrivate(modifiers: node.modifiers, declKeyword: node.funcKeyword)
             return super.visit(node.with(\.modifiers, modifiers).with(\.funcKeyword, declKeyword))
         }
@@ -189,16 +187,6 @@ private extension PrivateUnitTestRule {
 }
 
 private extension ClassDeclSyntax {
-    func hasParent(configuredIn config: PrivateUnitTestConfiguration) -> Bool {
-        inheritanceClause?.inheritedTypes.contains { type in
-            if let name = type.type.as(IdentifierTypeSyntax.self)?.name.text {
-                return config.regex.regex.numberOfMatches(in: name, range: name.fullNSRange) > 0
-                    || config.testParentClasses.contains(name)
-            }
-            return false
-        } ?? false
-    }
-
     var isPrivate: Bool {
         resultInPrivateProperty(modifiers: modifiers, attributes: attributes)
     }
