@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct ProhibitedSuperRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct ProhibitedSuperRule: Rule {
     var configuration = ProhibitedSuperConfiguration()
 
     static let description = RuleDescription(
