@@ -6,8 +6,8 @@ import SwiftSyntax
 /// of objects and the deinit should print a message or remove its instance from a
 /// list of allocations. Even having an empty deinit method is useful to provide
 /// a place to put a breakpoint when chasing down leaks.
-@SwiftSyntaxRule
-struct RequiredDeinitRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct RequiredDeinitRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
