@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct StrongIBOutletRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct StrongIBOutletRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -40,15 +40,14 @@ private extension StrongIBOutletRule {
 
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
         override func visit(_ node: VariableDeclSyntax) -> DeclSyntax {
-            guard let violationPosition = node.violationPosition,
+            guard node.violationPosition != nil,
                   let weakOrUnownedModifier = node.weakOrUnownedModifier,
                   case let modifiers = node.modifiers else {
                 return super.visit(node)
             }
-
             let newModifiers = modifiers.filter { $0 != weakOrUnownedModifier }
             let newNode = node.with(\.modifiers, newModifiers)
-            correctionPositions.append(violationPosition)
+            numberOfCorrections += 1
             return super.visit(newNode)
         }
     }
