@@ -1,3 +1,4 @@
+import Foundation
 import SwiftSyntax
 import SwiftSyntaxBuilder
 
@@ -56,7 +57,7 @@ private extension UnusedClosureParameterRule {
                           let index = params.parameters.index(of: param) else {
                         continue
                     }
-                    correctionPositions.append(name.positionAfterSkippingLeadingTrivia)
+                    numberOfCorrections += 1
                     let newParameterList = newParams.parameters.with(
                         \.[index],
                         param.with(\.firstName, name.with(\.tokenKind, .wildcard))
@@ -74,7 +75,7 @@ private extension UnusedClosureParameterRule {
                       let index = params.index(of: param) else {
                     continue
                 }
-                correctionPositions.append(param.name.positionAfterSkippingLeadingTrivia)
+                numberOfCorrections += 1
                 newParams = newParams.with(
                     \.[index],
                     param.with(\.name, param.name.with(\.tokenKind, .wildcard))
@@ -98,7 +99,7 @@ private final class IdentifierReferenceVisitor: SyntaxVisitor {
 
 private extension String {
     var removingDollarsAndBackticks: String {
-        self.replacingOccurrences(of: "$", with: "")
+        replacingOccurrences(of: "$", with: "")
             .replacingOccurrences(of: "`", with: "")
     }
 }
