@@ -30,18 +30,18 @@ struct UnusedDeclarationRule: AnalyzerRule, CollectingRule {
 
     func collectInfo(for file: SwiftLintFile, compilerArguments: [String]) -> Self.FileUSRs {
         guard compilerArguments.isNotEmpty else {
-            Issue.missingCompilerArguments(path: file.path, ruleID: Self.description.identifier).print()
+            Issue.missingCompilerArguments(path: file.path, ruleID: Self.identifier).print()
             return .empty
         }
 
         guard let index = file.index(compilerArguments: compilerArguments), index.value.isNotEmpty else {
-            Issue.indexingError(path: file.path, ruleID: Self.description.identifier).print()
+            Issue.indexingError(path: file.path, ruleID: Self.identifier).print()
             return .empty
         }
 
         guard let editorOpen = (try? Request.editorOpen(file: file.file).sendIfNotDisabled())
                 .map(SourceKittenDictionary.init) else {
-            Issue.fileNotReadable(path: file.path, ruleID: Self.description.identifier).print()
+            Issue.fileNotReadable(path: file.path, ruleID: Self.identifier).print()
             return .empty
         }
 
@@ -84,8 +84,7 @@ private extension SwiftLintFile {
     func index(compilerArguments: [String]) -> SourceKittenDictionary? {
         path
             .flatMap { path in
-                try? Request.index(file: path, arguments: compilerArguments)
-                            .send()
+                try? Request.index(file: path, arguments: compilerArguments).send()
             }
             .map(SourceKittenDictionary.init)
     }
@@ -162,9 +161,9 @@ private extension SwiftLintFile {
 
         // Skip CodingKeys as they are used for Codable generation
         if kind == .enum,
-            indexEntity.name == "CodingKeys",
-            case let allRelatedUSRs = indexEntity.traverseEntitiesDepthFirst(traverseBlock: { $1.usr }),
-            allRelatedUSRs.contains("s:s9CodingKeyP") {
+           indexEntity.name == "CodingKeys",
+           case let allRelatedUSRs = indexEntity.traverseEntitiesDepthFirst(traverseBlock: { $1.usr }),
+           allRelatedUSRs.contains("s:s9CodingKeyP") {
             return nil
         }
 
@@ -179,7 +178,7 @@ private extension SwiftLintFile {
             }
         }
 
-        let cursorInfo = self.cursorInfo(at: nameOffset, compilerArguments: compilerArguments)
+        let cursorInfo = cursorInfo(at: nameOffset, compilerArguments: compilerArguments)
 
         if cursorInfo?.annotatedDeclaration?.contains("@objc ") == true {
             return nil
@@ -195,7 +194,7 @@ private extension SwiftLintFile {
         // with "related names", which appears to be similarly named declarations (i.e. overloads) that are
         // programmatically unrelated to the current cursor-info declaration. Those similarly named declarations
         // aren't in `key.related` so confirm that that one is also populated.
-        if cursorInfo?.value["key.related_decls"] != nil && indexEntity.value["key.related"] != nil {
+        if cursorInfo?.value["key.related_decls"] != nil, indexEntity.value["key.related"] != nil {
             return nil
         }
 
@@ -211,6 +210,7 @@ private extension SwiftLintFile {
 
     private func shouldIgnoreEntity(_ indexEntity: SourceKittenDictionary, relatedUSRsToSkip: Set<String>) -> Bool {
         let declarationAttributesToSkip: Set<SwiftDeclarationAttributeKind> = [
+            .ibsegueaction,
             .ibaction,
             .main,
             .nsApplicationMain,
@@ -263,8 +263,8 @@ private extension SourceKittenDictionary {
 
     func propertyAtOffset<T>(_ offset: ByteCount, property: KeyPath<Self, T?>) -> T? {
         if let nameOffset,
-            nameOffset == offset,
-            let field = self[keyPath: property] {
+           nameOffset == offset,
+           let field = self[keyPath: property] {
             return field
         }
         for child in substructure {
@@ -282,7 +282,7 @@ private extension SourceKittenDictionary {
     }
 
     func shouldSkipIndexEntityToWorkAroundSR11985() -> Bool {
-        guard enclosedSwiftAttributes.contains(.objcName), let name = self.name else {
+        guard enclosedSwiftAttributes.contains(.objcName), let name else {
             return false
         }
 
