@@ -3,6 +3,7 @@ import SourceKittenFramework
 
 private let moduleToLog = ProcessInfo.processInfo.environment["SWIFTLINT_LOG_MODULE_USAGE"]
 
+@DisabledWithoutSourceKit
 struct UnusedImportRule: CorrectableRule, AnalyzerRule {
     var configuration = UnusedImportConfiguration()
 
@@ -26,25 +27,23 @@ struct UnusedImportRule: CorrectableRule, AnalyzerRule {
         }
     }
 
-    func correct(file: SwiftLintFile, compilerArguments: [String]) -> [Correction] {
+    func correct(file: SwiftLintFile, compilerArguments: [String]) -> Int {
         let importUsages = importUsage(in: file, compilerArguments: compilerArguments)
         let matches = file.ruleEnabled(violatingRanges: importUsages.compactMap(\.violationRange), for: self)
 
         var contents = file.stringView.nsString
-        let description = Self.description
-        var corrections = [Correction]()
+        var numberOfCorrections = 0
         for range in matches.reversed() {
             contents = contents.replacingCharacters(in: range, with: "").bridge()
-            let location = Location(file: file, characterOffset: range.location)
-            corrections.append(Correction(ruleDescription: description, location: location))
+            numberOfCorrections += 1
         }
 
-        if corrections.isNotEmpty {
+        if numberOfCorrections > 0 {
             file.write(contents.bridge())
         }
 
         guard configuration.requireExplicitImports else {
-            return corrections
+            return numberOfCorrections
         }
 
         let missingImports = importUsages.compactMap { importUsage -> String? in
@@ -57,7 +56,7 @@ struct UnusedImportRule: CorrectableRule, AnalyzerRule {
         }
 
         guard missingImports.isNotEmpty else {
-            return corrections
+            return numberOfCorrections
         }
 
         var insertionLocation = 0
@@ -72,19 +71,16 @@ struct UnusedImportRule: CorrectableRule, AnalyzerRule {
             .joined(separator: "\n")
         let newContents = contents.replacingCharacters(in: insertionRange, with: missingImportStatements + "\n")
         file.write(newContents)
-        let location = Location(file: file, characterOffset: 0)
-        let missingImportCorrections = missingImports.map { _ in
-            Correction(ruleDescription: description, location: location)
-        }
-        corrections.append(contentsOf: missingImportCorrections)
+        numberOfCorrections += missingImports.count
+
         // Attempt to sort imports
-        corrections.append(contentsOf: SortedImportsRule().correct(file: file))
-        return corrections
+        numberOfCorrections += SortedImportsRule().correct(file: file)
+        return numberOfCorrections
     }
 
     private func importUsage(in file: SwiftLintFile, compilerArguments: [String]) -> [ImportUsage] {
         guard compilerArguments.isNotEmpty else {
-            Issue.missingCompilerArguments(path: file.path, ruleID: Self.description.identifier).print()
+            Issue.missingCompilerArguments(path: file.path, ruleID: Self.identifier).print()
             return []
         }
 
@@ -105,7 +101,7 @@ private extension SwiftLintFile {
 
         var unusedImports = imports.subtracting(usrFragments).subtracting(configuration.alwaysKeepImports)
         // Certain Swift attributes requires importing Foundation.
-        if unusedImports.contains("Foundation") && containsAttributesRequiringFoundation() {
+        if unusedImports.contains("Foundation"), containsAttributesRequiringFoundation() {
             unusedImports.remove("Foundation")
         }
 
@@ -118,18 +114,12 @@ private extension SwiftLintFile {
             )
         }
 
-        let unusedImportUsages = rangedAndSortedUnusedImports(of: Array(unusedImports))
-            .map { ImportUsage.unused(module: $0, range: $1) }
-
-        guard configuration.requireExplicitImports else {
-            return unusedImportUsages
-        }
-
+        // Find the missing imports, which should be imported, but are not.
         let currentModule = (compilerArguments.firstIndex(of: "-module-name")?.advanced(by: 1))
             .map { compilerArguments[$0] }
 
-        let missingImports = usrFragments
-            .subtracting(imports + [currentModule].compactMap({ $0 }))
+        var missingImports = usrFragments
+            .subtracting(imports + [currentModule].compactMap(\.self))
             .filter { module in
                 let modulesAllowedToImportCurrentModule = configuration.allowedTransitiveImports
                     .filter { !unusedImports.contains($0.importedModule) }
@@ -140,7 +130,29 @@ private extension SwiftLintFile {
                     imports.isDisjoint(with: modulesAllowedToImportCurrentModule)
             }
 
-        return unusedImportUsages + missingImports.sorted().map { .missing(module: $0) }
+        // Check if unused imports were used for transitive imports
+        var foundUmbrellaModules = Set<String>()
+        var foundMissingImports = Set<String>()
+        for missingImport in missingImports {
+            let umbrellaModules = configuration.allowedTransitiveImports
+                .filter { $0.transitivelyImportedModules.contains(missingImport) }
+                .map(\.importedModule)
+            if umbrellaModules.isEmpty {
+                continue
+            }
+            foundMissingImports.insert(missingImport)
+            foundUmbrellaModules.formUnion(umbrellaModules.filter(unusedImports.contains))
+        }
+
+        unusedImports.subtract(foundUmbrellaModules)
+        missingImports.subtract(foundMissingImports)
+
+        let unusedImportUsages = rangedAndSortedUnusedImports(of: Array(unusedImports))
+            .map { ImportUsage.unused(module: $0, range: $1) }
+
+        return configuration.requireExplicitImports
+            ? unusedImportUsages + missingImports.sorted().map { .missing(module: $0) }
+            : unusedImportUsages
     }
 
     func getImportsAndUSRFragments(compilerArguments: [String]) -> (imports: Set<String>, usrFragments: Set<String>) {
@@ -162,13 +174,13 @@ private extension SwiftLintFile {
                 file: path!, offset: token.offset, arguments: compilerArguments
             )
             guard let cursorInfo = (try? cursorInfoRequest.sendIfNotDisabled()).map(SourceKittenDictionary.init) else {
-                Issue.missingCursorInfo(path: path, ruleID: UnusedImportRule.description.identifier).print()
+                Issue.missingCursorInfo(path: path, ruleID: UnusedImportRule.identifier).print()
                 continue
             }
             if nextIsModuleImport {
                 nextIsModuleImport = false
                 if let importedModule = cursorInfo.moduleName,
-                    cursorInfo.kind == "source.lang.swift.ref.module" {
+                   cursorInfo.kind == "source.lang.swift.ref.module" {
                     imports.insert(importedModule)
                     continue
                 }
@@ -196,20 +208,19 @@ private extension SwiftLintFile {
     // Operators are omitted in the editor.open request and thus have to be looked up by the indexsource request
     func operatorImports(arguments: [String], processedTokenOffsets: Set<ByteCount>) -> Set<String> {
         guard let index = (try? Request.index(file: path!, arguments: arguments).sendIfNotDisabled())
-            .map(SourceKittenDictionary.init) else {
-            Issue.indexingError(path: path, ruleID: UnusedImportRule.description.identifier).print()
+                .map(SourceKittenDictionary.init) else {
+            Issue.indexingError(path: path, ruleID: UnusedImportRule.identifier).print()
             return []
         }
 
         let operatorEntities = flatEntities(entity: index).filter { mightBeOperator(kind: $0.kind) }
-        let offsetPerLine = self.offsetPerLine()
+        let offsetPerLine = offsetPerLine()
         var imports = Set<String>()
 
         for entity in operatorEntities {
-            if
-                let line = entity.line,
-                let column = entity.column,
-                let lineOffset = offsetPerLine[Int(line) - 1] {
+            if let line = entity.line,
+               let column = entity.column,
+               let lineOffset = offsetPerLine[Int(line) - 1] {
                 let offset = lineOffset + column - 1
 
                 // Filter already processed tokens such as static methods that are not operators
@@ -219,8 +230,8 @@ private extension SwiftLintFile {
                     file: path!, offset: ByteCount(offset), arguments: arguments
                 )
                 guard let cursorInfo = (try? cursorInfoRequest.sendIfNotDisabled())
-                    .map(SourceKittenDictionary.init) else {
-                    Issue.missingCursorInfo(path: path, ruleID: UnusedImportRule.description.identifier).print()
+                        .map(SourceKittenDictionary.init) else {
+                    Issue.missingCursorInfo(path: path, ruleID: UnusedImportRule.identifier).print()
                     continue
                 }
 
