@@ -142,7 +142,7 @@ private extension UnusedSetterValueRule {
             let visitor = NewValueUsageVisitor(variableName: variableName)
             if !visitor.walk(tree: node, handler: \.isVariableUsed) {
                 if Syntax(node).closestVariableOrSubscript()?.modifiers?.contains(keyword: .override) == true,
-                    let body = node.body, body.statements.isEmpty {
+                   let body = node.body, body.statements.isEmpty {
                     return
                 }
 
@@ -170,10 +170,10 @@ private final class NewValueUsageVisitor: SyntaxVisitor {
 
 private extension Syntax {
     func closestVariableOrSubscript() -> Either<SubscriptDeclSyntax, VariableDeclSyntax>? {
-        if let subscriptDecl = self.as(SubscriptDeclSyntax.self) {
+        if let subscriptDecl = `as`(SubscriptDeclSyntax.self) {
             return .left(subscriptDecl)
         }
-        if let variableDecl = self.as(VariableDeclSyntax.self) {
+        if let variableDecl = `as`(VariableDeclSyntax.self) {
             return .right(variableDecl)
         }
 
