@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct WeakDelegateRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct WeakDelegateRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -74,8 +74,8 @@ private extension WeakDelegateRule {
         override func visitPost(_ node: VariableDeclSyntax) {
             guard node.hasDelegateSuffix,
                   node.weakOrUnownedModifier == nil,
-                 !node.hasComputedBody,
-                 !node.containsIgnoredAttribute,
+                  !node.hasComputedBody,
+                  !node.containsIgnoredAttribute,
                   let parent = node.parent,
                   Syntax(parent).enclosingClass() != nil else {
                 return
@@ -88,10 +88,10 @@ private extension WeakDelegateRule {
 
 private extension Syntax {
     func enclosingClass() -> ClassDeclSyntax? {
-        if let classExpr = self.as(ClassDeclSyntax.self) {
+        if let classExpr = `as`(ClassDeclSyntax.self) {
             return classExpr
         }
-        if self.as(DeclSyntax.self) != nil {
+        if `as`(DeclSyntax.self) != nil {
             return nil
         }
 
