@@ -1,8 +1,10 @@
+import SwiftLexicalLookup
 import SwiftLintCore
 import SwiftSyntax
+import SwiftSyntaxBuilder
 
-@SwiftSyntaxRule(foldExpressions: true, explicitRewriter: true)
-struct EmptyCountRule: OptInRule {
+@SwiftSyntaxRule(foldExpressions: true, explicitRewriter: true, optIn: true)
+struct EmptyCountRule: Rule {
     var configuration = EmptyCountConfiguration()
 
     static let description = RuleDescription(
@@ -20,6 +22,16 @@ struct EmptyCountRule: OptInRule {
             Example("[Int]().count == 0o07"),
             Example("discount == 0"),
             Example("order.discount == 0"),
+            Example("let rule = #Rule(Tips.Event(id: \"someTips\")) { $0.donations.count == 0 }"),
+            Example("#Rule(param1: \"param1\")", excludeFromDocumentation: true),
+            Example("func isEmpty(count: Int) -> Bool { count == 0 }"),
+            Example("""
+                var isEmpty: Bool {
+                    let count = 0
+                    return count == 0
+                }
+                """),
+            Example("{ count in count == 0 }()"),
         ],
         triggeringExamples: [
             Example("[Int]().↓count == 0"),
@@ -32,6 +44,34 @@ struct EmptyCountRule: OptInRule {
             Example("[Int]().↓count == 0b00"),
             Example("[Int]().↓count == 0o00"),
             Example("↓count == 0"),
+            Example("#ExampleMacro { $0.list.↓count == 0 }"),
+            Example("#Rule { $0.donations.↓count == 0 }", excludeFromDocumentation: true),
+            Example(
+                "#Rule(param1: \"param1\", param2: \"param2\") { $0.donations.↓count == 0 }",
+                excludeFromDocumentation: true
+            ),
+            Example(
+                "#Rule(param1: \"param1\") { $0.donations.↓count == 0 } closure2: { doSomething() }",
+                excludeFromDocumentation: true
+            ),
+            Example("#Rule(param1: \"param1\") { return $0.donations.↓count == 0 }", excludeFromDocumentation: true),
+            Example("""
+                #Rule(param1: "param1") {
+                    doSomething()
+                    return $0.donations.↓count == 0
+                }
+                """, excludeFromDocumentation: true),
+            Example("""
+                extension E {
+                    var isEmpty: Bool { ↓count == 0 }
+                }
+                """, excludeFromDocumentation: true),
+            Example(
+                """
+                struct S {
+                    var isEmpty: Bool { ↓count == 0 }
+                }
+                """, excludeFromDocumentation: true),
         ],
         corrections: [
             Example("[].↓count == 0"):
@@ -62,6 +102,10 @@ struct EmptyCountRule: OptInRule {
                 Example("isEmpty && [Int]().isEmpty"),
             Example("[Int]().count != 3 && [Int]().↓count != 0 || ↓count == 0 && [Int]().count > 2"):
                 Example("[Int]().count != 3 && ![Int]().isEmpty || isEmpty && [Int]().count > 2"),
+            Example("#ExampleMacro { $0.list.↓count == 0 }"):
+                Example("#ExampleMacro { $0.list.isEmpty }"),
+            Example("#Rule(param1: \"param1\") { return $0.donations.↓count == 0 }"):
+                Example("#Rule(param1: \"param1\") { return $0.donations.isEmpty }"),
         ]
     )
 }
@@ -77,6 +121,10 @@ private extension EmptyCountRule {
                 violations.append(position)
             }
         }
+
+        override func visit(_ node: MacroExpansionExprSyntax) -> SyntaxVisitorContinueKind {
+            node.isTipsRuleMacro ? .skipChildren : .visitChildren
+        }
     }
 
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
@@ -85,15 +133,17 @@ private extension EmptyCountRule {
                 return super.visit(node)
             }
 
-            if let (count, position) = node.countNodeAndPosition(onlyAfterDot: configuration.onlyAfterDot) {
+            if let (count, _) = node.countNodeAndPosition(onlyAfterDot: configuration.onlyAfterDot) {
                 let newNode =
                     if let count = count.as(MemberAccessExprSyntax.self) {
                         ExprSyntax(count.with(\.declName.baseName, "isEmpty").trimmed)
                     } else {
                         ExprSyntax(count.as(DeclReferenceExprSyntax.self)?.with(\.baseName, "isEmpty").trimmed)
                     }
-                guard let newNode else { return super.visit(node) }
-                correctionPositions.append(position)
+                guard let newNode else {
+                    return super.visit(node)
+                }
+                numberOfCorrections += 1
                 return
                     if ["!=", "<", ">"].contains(binaryOperator) {
                         newNode.negated
@@ -105,23 +155,43 @@ private extension EmptyCountRule {
             }
             return super.visit(node)
         }
+
+        override func visit(_ node: MacroExpansionExprSyntax) -> ExprSyntax {
+            if node.isTipsRuleMacro {
+                ExprSyntax(node)
+            } else {
+                super.visit(node)
+            }
+        }
     }
 }
 
 private extension ExprSyntax {
+    var isNonLocalCountIdentifier: Bool {
+        guard let declRef = `as`(DeclReferenceExprSyntax.self),
+              declRef.argumentNames == nil,
+              declRef.baseName.tokenKind == .identifier("count") else {
+            return false
+        }
+        let result = lookup(Identifier(canonicalName: "count"))
+        return result.isEmpty || !result.contains { result in
+            switch result {
+            case .fromScope: true
+            default: false
+            }
+        }
+    }
+
     func countCallPosition(onlyAfterDot: Bool) -> AbsolutePosition? {
-        if let expr = self.as(MemberAccessExprSyntax.self) {
-            if expr.declName.argumentNames == nil && expr.declName.baseName.tokenKind == .identifier("count") {
+        if let expr = `as`(MemberAccessExprSyntax.self) {
+            if expr.declName.argumentNames == nil, expr.declName.baseName.tokenKind == .identifier("count") {
                 return expr.declName.baseName.positionAfterSkippingLeadingTrivia
             }
-
             return nil
         }
-
-        if !onlyAfterDot, let expr = self.as(DeclReferenceExprSyntax.self) {
-            return expr.baseName.tokenKind == .identifier("count") ? expr.positionAfterSkippingLeadingTrivia : nil
+        if !onlyAfterDot, isNonLocalCountIdentifier {
+            return positionAfterSkippingLeadingTrivia
         }
-
         return nil
     }
 }
@@ -137,6 +207,15 @@ private extension TokenSyntax {
     }
 }
 
+private extension MacroExpansionExprSyntax {
+    var isTipsRuleMacro: Bool {
+        macroName.text == "Rule" &&
+        additionalTrailingClosures.isEmpty &&
+        arguments.count == 1 &&
+        trailingClosure.map { $0.statements.onlyElement?.item.is(ReturnStmtSyntax.self) == false } ?? false
+    }
+}
+
 private extension ExprSyntaxProtocol {
     var negated: ExprSyntax {
         ExprSyntax(PrefixOperatorExprSyntax(operator: .prefixOperator("!"), expression: self))
@@ -145,8 +224,7 @@ private extension ExprSyntaxProtocol {
 
 private extension SyntaxProtocol {
     func withTrivia(from node: some SyntaxProtocol) -> Self {
-        self
-            .with(\.leadingTrivia, node.leadingTrivia)
+        with(\.leadingTrivia, node.leadingTrivia)
             .with(\.trailingTrivia, node.trailingTrivia)
     }
 }
@@ -165,7 +243,7 @@ private extension InfixOperatorExprSyntax {
     }
 
     var binaryOperator: String? {
-        self.operator.as(BinaryOperatorExprSyntax.self)?.operator.binaryOperator
+        `operator`.as(BinaryOperatorExprSyntax.self)?.operator.binaryOperator
     }
 }
 
