@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct FirstWhereRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct FirstWhereRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -52,12 +52,12 @@ private extension FirstWhereRule {
 
 private extension ExprSyntax {
     var shouldSkip: Bool {
-        if self.is(StringLiteralExprSyntax.self) {
+        if `is`(StringLiteralExprSyntax.self) {
             return true
         }
-        if let functionCall = self.as(FunctionCallExprSyntax.self),
-                  let calledExpression = functionCall.calledExpression.as(DeclReferenceExprSyntax.self),
-                  calledExpression.baseName.text == "NSPredicate" {
+        if let functionCall = `as`(FunctionCallExprSyntax.self),
+           let calledExpression = functionCall.calledExpression.as(DeclReferenceExprSyntax.self),
+           calledExpression.baseName.text == "NSPredicate" {
             return true
         }
         return false
