@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct ReduceIntoRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct ReduceIntoRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -141,19 +141,17 @@ private extension FunctionCallExprSyntax {
 
 private extension ExprSyntax {
     var isCopyOnWriteType: Bool {
-        if self.is(StringLiteralExprSyntax.self) ||
-            self.is(DictionaryExprSyntax.self) ||
-            self.is(ArrayExprSyntax.self) {
+        if `is`(StringLiteralExprSyntax.self) || `is`(DictionaryExprSyntax.self) || `is`(ArrayExprSyntax.self) {
             return true
         }
 
-        if let expr = self.as(FunctionCallExprSyntax.self) {
+        if let expr = `as`(FunctionCallExprSyntax.self) {
             if let identifierExpr = expr.calledExpression.identifierExpr {
                 return identifierExpr.isCopyOnWriteType
             }
             if let memberAccesExpr = expr.calledExpression.as(MemberAccessExprSyntax.self),
-                      memberAccesExpr.declName.baseName.text == "init",
-                      let identifierExpr = memberAccesExpr.base?.identifierExpr {
+               memberAccesExpr.declName.baseName.text == "init",
+               let identifierExpr = memberAccesExpr.base?.identifierExpr {
                 return identifierExpr.isCopyOnWriteType
             }
             if expr.calledExpression.isCopyOnWriteType {
@@ -162,13 +160,13 @@ private extension ExprSyntax {
         }
 
         return false
-     }
+    }
 
     var identifierExpr: DeclReferenceExprSyntax? {
-        if let identifierExpr = self.as(DeclReferenceExprSyntax.self) {
+        if let identifierExpr = `as`(DeclReferenceExprSyntax.self) {
             return identifierExpr
         }
-        if let specializeExpr = self.as(GenericSpecializationExprSyntax.self) {
+        if let specializeExpr = `as`(GenericSpecializationExprSyntax.self) {
             return specializeExpr.expression.identifierExpr
         }
 
