@@ -3,13 +3,12 @@ import SwiftLintCore
 
 @AutoConfigParser
 struct ModifierOrderConfiguration: SeverityBasedRuleConfiguration {
-    typealias Parent = ModifierOrderRule
-
     @ConfigurationElement(key: "severity")
     private(set) var severityConfiguration = SeverityConfiguration<Parent>(.warning)
     @ConfigurationElement(key: "preferred_modifier_order")
     private(set) var preferredModifierOrder: [SwiftDeclarationAttributeKind.ModifierGroup] = [
         .override,
+        .isolation,
         .acl,
         .setterACL,
         .dynamic,
@@ -24,11 +23,11 @@ struct ModifierOrderConfiguration: SeverityBasedRuleConfiguration {
 }
 
 extension SwiftDeclarationAttributeKind.ModifierGroup: AcceptableByConfigurationElement {
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         if let value = value as? String, let newSelf = Self(rawValue: value), newSelf != .atPrefixed {
             self = newSelf
         } else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+            throw .invalidConfiguration(ruleID: ruleID)
         }
     }
 
