@@ -49,9 +49,9 @@ struct NameConfiguration<Parent: Rule>: RuleConfiguration, InlinableOptionType {
         self.validatesStartWithLowercase = validatesStartWithLowercase
     }
 
-    mutating func apply(configuration: Any) throws {
+    mutating func apply(configuration: Any) throws(Issue) {
         guard let configurationDict = configuration as? [String: Any] else {
-            throw Issue.invalidConfiguration(ruleID: Parent.identifier)
+            throw .invalidConfiguration(ruleID: Parent.identifier)
         }
 
         if let minLengthConfiguration = configurationDict[$minLength.key] {
@@ -61,7 +61,7 @@ struct NameConfiguration<Parent: Rule>: RuleConfiguration, InlinableOptionType {
             try maxLength.apply(configuration: maxLengthConfiguration)
         }
         if let excluded = [String].array(of: configurationDict[$excludedRegularExpressions.key]) {
-            self.excludedRegularExpressions = Set(excluded.compactMap {
+            excludedRegularExpressions = Set(excluded.compactMap {
                 try? RegularExpression(pattern: "^\($0)$")
             })
         }
@@ -73,16 +73,6 @@ struct NameConfiguration<Parent: Rule>: RuleConfiguration, InlinableOptionType {
         }
         if let validatesStartWithLowercase = configurationDict[$validatesStartWithLowercase.key] as? String {
             try self.validatesStartWithLowercase.apply(configuration: validatesStartWithLowercase)
-        } else if let validatesStartWithLowercase = configurationDict[$validatesStartWithLowercase.key] as? Bool {
-            // TODO: [05/10/2025] Remove deprecation warning after ~2 years.
-            self.validatesStartWithLowercase = validatesStartWithLowercase ? .error : .off
-            Issue.genericWarning(
-                """
-                The \"validates_start_with_lowercase\" configuration now expects a severity (warning or \
-                error). The boolean value 'true' will still enable it as an error. It is now deprecated and will be \
-                removed in a future release.
-                """
-            ).print()
         }
     }
 }
