@@ -2,7 +2,6 @@ import SwiftLintCore
 
 @AutoConfigParser
 struct NestingConfiguration: RuleConfiguration {
-    typealias Parent = NestingRule
     typealias Severity = SeverityLevelsConfiguration<Parent>
 
     @ConfigurationElement(key: "type_level")
@@ -15,6 +14,8 @@ struct NestingConfiguration: RuleConfiguration {
     private(set) var alwaysAllowOneTypeInFunctions = false
     @ConfigurationElement(key: "ignore_typealiases_and_associatedtypes")
     private(set) var ignoreTypealiasesAndAssociatedtypes = false
+    @ConfigurationElement(key: "ignore_coding_keys")
+    private(set) var ignoreCodingKeys = false
 
     func severity(with config: Severity, for level: Int) -> ViolationSeverity? {
         if let error = config.error, level > error {
