@@ -2,8 +2,6 @@ import SwiftLintCore
 
 @AutoConfigParser
 struct OverriddenSuperCallConfiguration: SeverityBasedRuleConfiguration {
-    typealias Parent = OverriddenSuperCallRule
-
     private static let defaultIncluded = [
         // NSObject
         "awakeFromNib()",
@@ -45,7 +43,7 @@ struct OverriddenSuperCallConfiguration: SeverityBasedRuleConfiguration {
 
     var resolvedMethodNames: [String] {
         var names: [String] = []
-        if included.contains("*") && !excluded.contains("*") {
+        if included.contains("*"), !excluded.contains("*") {
             names += Self.defaultIncluded
         }
         names += included.filter { $0 != "*" }
