@@ -2,8 +2,6 @@ import SwiftLintCore
 
 @AutoConfigParser
 struct ProhibitedSuperConfiguration: SeverityBasedRuleConfiguration {
-    typealias Parent = ProhibitedSuperRule
-
     @ConfigurationElement(key: "severity")
     private(set) var severityConfiguration = SeverityConfiguration<Parent>(.warning)
     @ConfigurationElement(key: "excluded")
@@ -24,7 +22,7 @@ struct ProhibitedSuperConfiguration: SeverityBasedRuleConfiguration {
 
     var resolvedMethodNames: [String] {
         var names = [String]()
-        if included.contains("*") && !excluded.contains("*") {
+        if included.contains("*"), !excluded.contains("*") {
             names += Self.methodNames
         }
         names += included.filter { $0 != "*" }
