@@ -2,10 +2,8 @@ import SwiftLintCore
 
 @AutoConfigParser
 struct SortedImportsConfiguration: SeverityBasedRuleConfiguration {
-    typealias Parent = SortedImportsRule
-
     @AcceptableByConfigurationElement
-    enum SortedImportsGroupingConfiguration: String {
+    enum Grouping: String {
         /// Sorts import lines based on any import attributes (e.g. `@testable`, `@_exported`, etc.), followed by a case
         /// insensitive comparison of the imported module name.
         case attributes
@@ -16,5 +14,5 @@ struct SortedImportsConfiguration: SeverityBasedRuleConfiguration {
     @ConfigurationElement(key: "severity")
     private(set) var severityConfiguration = SeverityConfiguration<Parent>(.warning)
     @ConfigurationElement(key: "grouping")
-    private(set) var grouping = SortedImportsGroupingConfiguration.names
+    private(set) var grouping = Grouping.names
 }
