@@ -17,12 +17,11 @@ enum TypeContent: String {
     case otherMethod = "other_method"
     case `subscript` = "subscript"
     case deinitializer = "deinitializer"
+    case ibSegueAction = "ib_segue_action"
 }
 
 @AutoConfigParser
 struct TypeContentsOrderConfiguration: SeverityBasedRuleConfiguration {
-    typealias Parent = TypeContentsOrderRule
-
     @ConfigurationElement(key: "severity")
     private(set) var severityConfiguration = SeverityConfiguration<Parent>(.warning)
     @ConfigurationElement(key: "order")
@@ -37,7 +36,7 @@ struct TypeContentsOrderConfiguration: SeverityBasedRuleConfiguration {
         [.initializer],
         [.typeMethod],
         [.viewLifeCycleMethod],
-        [.ibAction],
+        [.ibAction, .ibSegueAction],
         [.otherMethod],
         [.subscript],
         [.deinitializer],
