@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct AttributesRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct AttributesRule: Rule {
     var configuration = AttributesConfiguration()
 
     static let description = RuleDescription(
@@ -11,6 +11,22 @@ struct AttributesRule: OptInRule {
             Attributes should be on their own lines in functions and types, but on the same line as variables and \
             imports
             """,
+        rationale: """
+        Erica Sadun says:
+
+        > My take on things after the poll and after talking directly with a number of \
+        developers is this: Placing attributes like `@objc`, `@testable`, `@available`, `@discardableResult` on \
+        their own lines before a member declaration has become a conventional Swift style.
+
+        > This approach limits declaration length. It allows a member to float below its attribute and supports \
+        flush-left access modifiers, so `internal`, `public`, etc appear in the leftmost column. Many developers \
+        mix-and-match styles for short Swift attributes like `@objc`
+
+        See https://ericasadun.com/2016/10/02/quick-style-survey/ for discussion.
+
+        SwiftLint's rule requires attributes to be on their own lines for functions and types, but on the same line \
+        for variables and imports.
+        """,
         kind: .style,
         nonTriggeringExamples: AttributesRuleExamples.nonTriggeringExamples,
         triggeringExamples: AttributesRuleExamples.triggeringExamples
@@ -70,7 +86,7 @@ private extension AttributesRule {
             }
 
             let hasMultipleNewlines = node.children(viewMode: .sourceAccurate).enumerated().contains { index, element in
-                if index > 0 && element.leadingTrivia.hasMultipleNewlines == true {
+                if index > 0, element.leadingTrivia.hasMultipleNewlines == true {
                     return true
                 }
                 return element.trailingTrivia.hasMultipleNewlines == true
@@ -146,7 +162,7 @@ private struct RuleHelper {
                     linesWithAttributes.contains(attributeStartLine)
                 linesWithAttributes.insert(attributeStartLine)
                 if hasViolation {
-                    if attributesWithArgumentsAlwaysOnNewLine && shouldBeOnSameLine {
+                    if attributesWithArgumentsAlwaysOnNewLine, shouldBeOnSameLine {
                         return .argumentsAlwaysOnNewLineViolation
                     }
                     return .violation
@@ -160,8 +176,7 @@ private struct RuleHelper {
 private extension AttributeListSyntax {
     func attributesAndPlacements(configuration: AttributesConfiguration, shouldBeOnSameLine: Bool)
         -> [(AttributeSyntax, AttributePlacement)] {
-        self
-            .children(viewMode: .sourceAccurate)
+        children(viewMode: .sourceAccurate)
             .compactMap { $0.as(AttributeSyntax.self) }
             .map { attribute in
                 let atPrefixedName = "@\(attribute.attributeNameText)"
