@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct ClosureSpacingRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct ClosureSpacingRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -79,9 +79,8 @@ private extension ClosureSpacingRule {
                 node.rightBrace = node.rightBrace.with(\.trailingTrivia, .spaces(1))
             }
             if violations.hasViolations {
-                correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+                numberOfCorrections += 1
             }
-
             return super.visit(node)
         }
     }
@@ -137,7 +136,7 @@ private extension TokenSyntax {
             return true
         }
         if let previousToken = previousToken(viewMode: .sourceAccurate),
-                  case .spaces(1) = Array(previousToken.trailingTrivia).last {
+           case .spaces(1) = Array(previousToken.trailingTrivia).last {
             return true
         }
         return false
@@ -148,7 +147,7 @@ private extension TokenSyntax {
             return true
         }
         if let nextToken = nextToken(viewMode: .sourceAccurate),
-                  case .spaces(1) = nextToken.leadingTrivia.first {
+           case .spaces(1) = nextToken.leadingTrivia.first {
             return true
         }
         return false
@@ -198,7 +197,7 @@ private extension TokenSyntax {
             return true
         }
         if let nextToken = nextToken(viewMode: .sourceAccurate),
-                  allowedKinds.contains(nextToken.tokenKind) {
+           allowedKinds.contains(nextToken.tokenKind) {
             return true
         }
         return false
