@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct CollectionAlignmentRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct CollectionAlignmentRule: Rule {
     var configuration = CollectionAlignmentConfiguration()
 
     static let description = RuleDescription(
@@ -26,7 +26,7 @@ private extension CollectionAlignmentRule {
         override func visitPost(_ node: DictionaryElementListSyntax) {
             let locations = node.map { element in
                 let position = configuration.alignColons ? element.colon.positionAfterSkippingLeadingTrivia :
-                element.key.positionAfterSkippingLeadingTrivia
+                    element.key.positionAfterSkippingLeadingTrivia
                 let location = locationConverter.location(for: position)
 
                 let graphemeColumn: Int
