@@ -29,6 +29,8 @@ struct ControlStatementRule: Rule {
             Example("switch (lhs, rhs) {}"),
             Example("if (f() { g() {} }) {}"),
             Example("if (a + f() {} == 1) {}"),
+            Example("if ({ true }()) {}"),
+            Example("if ({if i < 1 { true } else { false }}()) {}", excludeFromDocumentation: true),
         ],
         triggeringExamples: [
             Example("↓if (condition) {}"),
@@ -112,7 +114,7 @@ private extension ControlStatementRule {
             guard case let items = node.catchItems, items.containSuperfluousParens == true else {
                 return super.visit(node)
             }
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let node = node
                 .with(\.catchKeyword, node.catchKeyword.with(\.trailingTrivia, .space))
                 .with(\.catchItems, items.withoutParens)
@@ -123,7 +125,7 @@ private extension ControlStatementRule {
             guard node.conditions.containSuperfluousParens else {
                 return super.visit(node)
             }
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let node = node
                 .with(\.guardKeyword, node.guardKeyword.with(\.trailingTrivia, .space))
                 .with(\.conditions, node.conditions.withoutParens)
@@ -134,7 +136,7 @@ private extension ControlStatementRule {
             guard node.conditions.containSuperfluousParens else {
                 return super.visit(node)
             }
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let node = node
                 .with(\.ifKeyword, node.ifKeyword.with(\.trailingTrivia, .space))
                 .with(\.conditions, node.conditions.withoutParens)
@@ -145,7 +147,7 @@ private extension ControlStatementRule {
             guard let tupleElement = node.subject.unwrapped else {
                 return super.visit(node)
             }
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let node = node
                 .with(\.switchKeyword, node.switchKeyword.with(\.trailingTrivia, .space))
                 .with(\.subject, tupleElement.with(\.trailingTrivia, .space))
@@ -156,7 +158,7 @@ private extension ControlStatementRule {
             guard node.conditions.containSuperfluousParens else {
                 return super.visit(node)
             }
-            correctionPositions.append(node.positionAfterSkippingLeadingTrivia)
+            numberOfCorrections += 1
             let node = node
                 .with(\.whileKeyword, node.whileKeyword.with(\.trailingTrivia, .space))
                 .with(\.conditions, node.conditions.withoutParens)
@@ -167,16 +169,16 @@ private extension ControlStatementRule {
 
 private extension ExprSyntax {
     var unwrapped: ExprSyntax? {
-        if let expr = self.as(TupleExprSyntax.self)?.elements.onlyElement?.expression {
+        if let expr = `as`(TupleExprSyntax.self)?.elements.onlyElement?.expression {
             return containsTrailingClosure(Syntax(expr)) ? nil : expr
         }
         return nil
     }
 
-   private func containsTrailingClosure(_ node: Syntax) -> Bool {
+    private func containsTrailingClosure(_ node: Syntax) -> Bool {
         switch node.as(SyntaxEnum.self) {
         case .functionCallExpr(let node):
-            node.trailingClosure != nil
+            node.trailingClosure != nil || node.calledExpression.is(ClosureExprSyntax.self)
         case .sequenceExpr(let node):
             node.elements.contains { containsTrailingClosure(Syntax($0)) }
         default: false
