@@ -23,26 +23,23 @@ struct ExplicitSelfRule: CorrectableRule, AnalyzerRule {
         }
     }
 
-    func correct(file: SwiftLintFile, compilerArguments: [String]) -> [Correction] {
+    func correct(file: SwiftLintFile, compilerArguments: [String]) -> Int {
         let violations = violationRanges(in: file, compilerArguments: compilerArguments)
         let matches = file.ruleEnabled(violatingRanges: violations, for: self)
-        if matches.isEmpty { return [] }
-
+        if matches.isEmpty {
+            return 0
+        }
         var contents = file.contents.bridge()
-        let description = Self.description
-        var corrections = [Correction]()
         for range in matches.reversed() {
             contents = contents.replacingCharacters(in: range, with: "self.").bridge()
-            let location = Location(file: file, characterOffset: range.location)
-            corrections.append(Correction(ruleDescription: description, location: location))
         }
         file.write(contents.bridge())
-        return corrections
+        return matches.count
     }
 
     private func violationRanges(in file: SwiftLintFile, compilerArguments: [String]) -> [NSRange] {
         guard compilerArguments.isNotEmpty else {
-            Issue.missingCompilerArguments(path: file.path, ruleID: Self.description.identifier).print()
+            Issue.missingCompilerArguments(path: file.path, ruleID: Self.identifier).print()
             return []
         }
 
@@ -69,7 +66,7 @@ struct ExplicitSelfRule: CorrectableRule, AnalyzerRule {
 
         return cursorsMissingExplicitSelf.compactMap { cursorInfo in
             guard let byteOffset = (cursorInfo["swiftlint.offset"] as? Int64).flatMap(ByteCount.init) else {
-                Issue.genericWarning("Cannot convert offsets in '\(Self.description.identifier)' rule.").print()
+                Issue.genericWarning("Cannot convert offsets in '\(Self.identifier)' rule.").print()
                 return nil
             }
 
@@ -122,10 +119,10 @@ private extension StringView {
     func recursiveByteOffsets(_ dict: [String: Any]) -> [ByteCount] {
         let cur: [ByteCount]
         if let line = dict["key.line"] as? Int64,
-            let column = dict["key.column"] as? Int64,
-            let kindString = dict["key.kind"] as? String,
-            kindsToFind.contains(kindString),
-            let offset = byteOffset(forLine: line, bytePosition: column) {
+           let column = dict["key.column"] as? Int64,
+           let kindString = dict["key.kind"] as? String,
+           kindsToFind.contains(kindString),
+           let offset = byteOffset(forLine: line, bytePosition: column) {
             cur = [offset]
         } else {
             cur = []
