@@ -81,6 +81,16 @@ private extension IdentifierNameRule {
             )
         }
 
+        override func visitPost(_ node: GenericParameterSyntax) {
+            guard node.specifier?.tokenKind == .keyword(.let) else {
+                return
+            }
+            collectViolations(
+                from: .variable(name: node.name.text, isStatic: false, isPrivate: false),
+                on: node.name
+            )
+        }
+
         override func visitPost(_ node: IdentifierPatternSyntax) {
             let varDecl = node.enclosingVarDecl
             if varDecl?.modifiers.contains(keyword: .override) ?? false {
@@ -146,12 +156,6 @@ private extension IdentifierNameRule {
     }
 }
 
-private extension DeclModifierListSyntax {
-    var staticOrClassModifier: DeclModifierSyntax? {
-        first { ["static", "class"].contains($0.name.text) }
-    }
-}
-
 private extension IdentifierPatternSyntax {
     var enclosingVarDecl: VariableDeclSyntax? {
         let identifierDecl =
@@ -171,24 +175,6 @@ private extension IdentifierPatternSyntax {
     }
 }
 
-private extension VariableDeclSyntax {
-    var allDeclaredNames: [String] {
-        bindings
-            .map(\.pattern)
-            .flatMap { pattern -> [String] in
-                if let id = pattern.as(IdentifierPatternSyntax.self) {
-                    [id.identifier.text]
-                } else if let tuple = pattern.as(TuplePatternSyntax.self) {
-                    tuple.elements.compactMap {
-                        $0.pattern.as(IdentifierPatternSyntax.self)?.identifier.text
-                    }
-                } else {
-                    []
-                }
-            }
-    }
-}
-
 private enum NamedDeclType: CustomStringConvertible {
     case function(name: String, resolvedName: String, isPrivate: Bool)
     case enumElement(name: String)
