@@ -30,14 +30,12 @@ internal struct IdentifierNameRuleExamples {
                 }
                 """),
         Example("func √ (arg: Double) -> Double { arg }", configuration: ["additional_operators": "√"]),
+        Example("struct Foo<let count: Int> {}"),
+        Example("struct Foo<let maxSize: Int, Element> {}"),
+        Example("class Foo<let capacity: Int> {}"),
     ]
 
     static let triggeringExamples = [
-        Example(
-            "let ↓MyLet = 0",
-            configuration: ["validates_start_with_lowercase": true],
-            excludeFromDocumentation: true
-        ),
         Example("class C { static let ↓_myLet = 0 }"),
         Example("class C { class let ↓MyLet = 0 }"),
         Example("class C { static func ↓MyFunc() {} }"),
@@ -96,5 +94,7 @@ internal struct IdentifierNameRuleExamples {
             }
             """),
         Example("func ↓√ (arg: Double) -> Double { arg }"),
+        Example("class Foo<let ↓max_count: Int> {}"),
+        Example("struct Foo<let ↓c: Int> {}"),
     ]
 }
