@@ -1,6 +1,7 @@
 import Foundation
 import SourceKittenFramework
 
+@DisabledWithoutSourceKit
 struct IndentationWidthRule: OptInRule {
     // MARK: - Subtypes
     private enum Indentation: Equatable {
@@ -61,7 +62,7 @@ struct IndentationWidthRule: OptInRule {
 
             // Determine indentation
             let indentation: Indentation
-            if tabCount != 0 && spaceCount != 0 {
+            if tabCount != 0, spaceCount != 0 {
                 // Catch mixed indentation
                 violations.append(
                     StyleViolation(
