@@ -1,8 +1,8 @@
 import SwiftLintCore
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct LetVarWhitespaceRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct LetVarWhitespaceRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -215,7 +215,7 @@ struct LetVarWhitespaceRule: OptInRule {
 private extension LetVarWhitespaceRule {
     final class Visitor: ViolationsSyntaxVisitor<ConfigurationType> {
         override func visitPost(_ node: MemberBlockItemListSyntax) {
-            collectViolations(from: node, using: { $0.decl }) // swiftlint:disable:this prefer_key_path
+            collectViolations(from: node, using: \.decl)
         }
 
         override func visitPost(_ node: CodeBlockItemListSyntax) {
