@@ -1,6 +1,7 @@
 import Foundation
 import SourceKittenFramework
 
+@DisabledWithoutSourceKit
 struct LiteralExpressionEndIndentationRule: Rule, OptInRule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
@@ -142,42 +143,31 @@ struct LiteralExpressionEndIndentationRule: Rule, OptInRule {
 }
 
 extension LiteralExpressionEndIndentationRule: CorrectableRule {
-    func correct(file: SwiftLintFile) -> [Correction] {
+    func correct(file: SwiftLintFile) -> Int {
         let allViolations = violations(in: file).reversed().filter { violation in
             guard let nsRange = file.stringView.byteRangeToNSRange(violation.range) else {
                 return false
             }
-
             return file.ruleEnabled(violatingRanges: [nsRange], for: self).isNotEmpty
         }
-
         guard allViolations.isNotEmpty else {
-            return []
+            return 0
         }
-
         var correctedContents = file.contents
-        var correctedLocations: [Int] = []
-
         let actualLookup = actualViolationLookup(for: allViolations)
-
+        var numberOfCorrections = 0
         for violation in allViolations {
             let expected = actualLookup(violation).indentationRanges.expected
             let actual = violation.indentationRanges.actual
             if correct(contents: &correctedContents, expected: expected, actual: actual) {
-                correctedLocations.append(actual.location)
+                numberOfCorrections += 1
             }
         }
-
-        var corrections = correctedLocations.map {
-            Correction(ruleDescription: Self.description, location: Location(file: file, characterOffset: $0))
-        }
-
         file.write(correctedContents)
 
         // Re-correct to catch cascading indentation from the first round.
-        corrections += correct(file: file)
-
-        return corrections
+        numberOfCorrections += correct(file: file)
+        return numberOfCorrections
     }
 
     private func correct(contents: inout String, expected: NSRange, actual: NSRange) -> Bool {
@@ -231,17 +221,17 @@ extension LiteralExpressionEndIndentationRule {
 
         let contents = file.stringView
         guard elements.isNotEmpty,
-            let offset = dictionary.offset,
-            let length = dictionary.length,
-            let (startLine, _) = contents.lineAndCharacter(forByteOffset: offset),
-            let firstParamOffset = elements[0].offset,
-            let (firstParamLine, _) = contents.lineAndCharacter(forByteOffset: firstParamOffset),
-            startLine != firstParamLine,
-            let lastParamOffset = elements.last?.offset,
-            let (lastParamLine, _) = contents.lineAndCharacter(forByteOffset: lastParamOffset),
-            case let endOffset = offset + length - 1,
-            let (endLine, endPosition) = contents.lineAndCharacter(forByteOffset: endOffset),
-            lastParamLine != endLine
+              let offset = dictionary.offset,
+              let length = dictionary.length,
+              let (startLine, _) = contents.lineAndCharacter(forByteOffset: offset),
+              let firstParamOffset = elements[0].offset,
+              let (firstParamLine, _) = contents.lineAndCharacter(forByteOffset: firstParamOffset),
+              startLine != firstParamLine,
+              let lastParamOffset = elements.last?.offset,
+              let (lastParamLine, _) = contents.lineAndCharacter(forByteOffset: lastParamOffset),
+              case let endOffset = offset + length - 1,
+              let (endLine, endPosition) = contents.lineAndCharacter(forByteOffset: endOffset),
+              lastParamLine != endLine
         else {
             return nil
         }
@@ -250,8 +240,8 @@ extension LiteralExpressionEndIndentationRule {
         let regex = Self.notWhitespace
         let actual = endPosition - 1
         guard let match = regex.firstMatch(in: file.contents, options: [], range: range)?.range,
-            case let expected = match.location - range.location,
-            expected != actual
+              case let expected = match.location - range.location,
+              expected != actual
         else {
             return nil
         }
