@@ -1,8 +1,8 @@
 import Foundation
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct MultilineLiteralBracketsRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct MultilineLiteralBracketsRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -145,7 +145,7 @@ private extension MultilineLiteralBracketsRule {
                               firstElement: (some ExprSyntaxProtocol)?,
                               lastElement: (some ExprSyntaxProtocol)?) {
             guard let firstElement, let lastElement,
-                    isMultiline(node) else {
+                  isMultiline(node) else {
                 return
             }
 
