@@ -1,6 +1,7 @@
 import Foundation
 import SourceKittenFramework
 
+@DisabledWithoutSourceKit
 struct MultilineParametersBracketsRule: OptInRule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
@@ -99,7 +100,7 @@ struct MultilineParametersBracketsRule: OptInRule {
 
         // find violations at current level
         if let kind = substructure.declarationKind,
-            SwiftDeclarationKind.functionKinds.contains(kind) {
+           SwiftDeclarationKind.functionKinds.contains(kind) {
             guard
                 let nameOffset = substructure.nameOffset,
                 let nameLength = substructure.nameLength,
@@ -117,7 +118,7 @@ struct MultilineParametersBracketsRule: OptInRule {
             let declarationNewlineCount = functionName.countOccurrences(of: "\n")
             let isMultiline = declarationNewlineCount > parametersNewlineCount
 
-            if isMultiline && parameters.isNotEmpty {
+            if isMultiline, parameters.isNotEmpty {
                 if let openingBracketViolation = openingBracketViolation(parameters: parameters, file: file) {
                     violations.append(openingBracketViolation)
                 }
