@@ -1,8 +1,8 @@
 import Foundation
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct NumberSeparatorRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct NumberSeparatorRule: Rule {
     var configuration = NumberSeparatorConfiguration()
 
     static let description = RuleDescription(
@@ -55,7 +55,7 @@ private extension NumberSeparatorRule {
                     .floatLiteral(violation.correction)
                 )
             )
-            correctionPositions.append(violation.position)
+            numberOfCorrections += 1
             return super.visit(newNode)
         }
 
@@ -64,7 +64,7 @@ private extension NumberSeparatorRule {
                 return super.visit(node)
             }
             let newNode = node.with(\.literal, node.literal.with(\.tokenKind, .integerLiteral(violation.correction)))
-            correctionPositions.append(violation.position)
+            numberOfCorrections += 1
             return super.visit(newNode)
         }
     }
@@ -104,15 +104,15 @@ private extension NumberSeparatorValidator {
     func violation(token: TokenSyntax) -> NumberSeparatorViolation? {
         let content = token.text
         guard isDecimal(number: content),
-            !isInValidRanges(number: content)
+              !isInValidRanges(number: content)
         else {
             return nil
         }
 
         let exponential = CharacterSet(charactersIn: "eE")
         guard case let exponentialComponents = content.components(separatedBy: exponential),
-            let nonExponential = exponentialComponents.first else {
-                return nil
+              let nonExponential = exponentialComponents.first else {
+            return nil
         }
 
         let components = nonExponential.components(separatedBy: ".")
@@ -124,8 +124,8 @@ private extension NumberSeparatorValidator {
         }
 
         guard let integerSubstring = components.first,
-            case let (valid, expected) = isValid(number: integerSubstring, isFraction: false),
-            !valid || !validFraction
+              case let (valid, expected) = isValid(number: integerSubstring, isFraction: false),
+              !valid || !validFraction
         else {
             return nil
         }
@@ -180,7 +180,7 @@ private extension NumberSeparatorValidator {
             defer { correctComponents.append(String(char)) }
             guard char.unicodeScalars.allSatisfy(CharacterSet.decimalDigits.contains) else { continue }
 
-            if numerals.isMultiple(of: 3) && numerals > 0 && shouldAddSeparators {
+            if numerals.isMultiple(of: 3), numerals > 0, shouldAddSeparators {
                 correctComponents.append("_")
             }
             numerals += 1
