@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct OptionalEnumCaseMatchingRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct OptionalEnumCaseMatchingRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -151,6 +151,21 @@ struct OptionalEnumCaseMatchingRule: OptInRule {
              default: break
             }
             """),
+            Example("""
+            switch foo {
+             case (true?, false?): break
+             case (true?, _): break
+             case (_, false?): break
+             default: break
+            }
+            """): Example("""
+            switch foo {
+             case (true?, false?): break
+             case (true?, _): break
+             case (_, false?): break
+             default: break
+            }
+            """),
         ]
     )
 }
@@ -185,8 +200,7 @@ private extension OptionalEnumCaseMatchingRule {
 
             if let expression = pattern.expression.as(OptionalChainingExprSyntax.self),
                !expression.expression.isDiscardAssignmentOrBoolLiteral {
-                let violationPosition = expression.questionMark.positionAfterSkippingLeadingTrivia
-                correctionPositions.append(violationPosition)
+                numberOfCorrections += 1
                 let newPattern = PatternSyntax(pattern.with(\.expression, expression.expression))
                 let newNode = node
                     .with(\.pattern, newPattern)
@@ -199,14 +213,11 @@ private extension OptionalEnumCaseMatchingRule {
                 for element in expression.elements {
                     guard
                         let optionalChainingExpression = element.expression.as(OptionalChainingExprSyntax.self),
-                        !optionalChainingExpression.expression.is(DiscardAssignmentExprSyntax.self)
+                        !optionalChainingExpression.expression.isDiscardAssignmentOrBoolLiteral
                     else {
                         continue
                     }
-
-                    let violationPosition = optionalChainingExpression.questionMark.positionAfterSkippingLeadingTrivia
-                    correctionPositions.append(violationPosition)
-
+                    numberOfCorrections += 1
                     let newElement = element.with(\.expression, optionalChainingExpression.expression)
                     if let index = expression.elements.index(of: element) {
                         newExpression.elements = newExpression.elements.with(\.[index], newElement)
