@@ -1,7 +1,8 @@
 import SwiftSyntax
+import SwiftSyntaxBuilder
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct PreferSelfTypeOverTypeOfSelfRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct PreferSelfTypeOverTypeOfSelfRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -121,9 +122,7 @@ private extension PreferSelfTypeOverTypeOfSelfRule {
             guard let function = node.base?.as(FunctionCallExprSyntax.self), function.hasViolation else {
                 return super.visit(node)
             }
-
-            correctionPositions.append(function.positionAfterSkippingLeadingTrivia)
-
+            numberOfCorrections += 1
             let base = DeclReferenceExprSyntax(baseName: "Self")
             let baseWithTrivia = base
                 .with(\.leadingTrivia, function.leadingTrivia)
