@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct ReturnArrowWhitespaceRule: SwiftSyntaxCorrectableRule {
+@SwiftSyntaxRule(correctable: true)
+struct ReturnArrowWhitespaceRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -87,7 +87,7 @@ private extension TokenSyntax {
         var end: AbsolutePosition?
         var correction = " -> "
 
-        if previousToken.trailingTrivia != .space && !leadingTrivia.containsNewlines() {
+        if previousToken.trailingTrivia != .space, !leadingTrivia.containsNewlines() {
             start = previousToken.endPositionBeforeTrailingTrivia
             end = endPosition
 
@@ -96,7 +96,7 @@ private extension TokenSyntax {
             }
         }
 
-        if trailingTrivia != .space && !nextToken.leadingTrivia.containsNewlines() {
+        if trailingTrivia != .space, !nextToken.leadingTrivia.containsNewlines() {
             if leadingTrivia.containsNewlines() {
                 start = positionAfterSkippingLeadingTrivia
                 correction = "-> "
