@@ -2,8 +2,8 @@ import SwiftSyntax
 
 // MARK: - SelfBindingRule
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct SelfBindingRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct SelfBindingRule: Rule {
     var configuration = SelfBindingConfiguration()
 
     static let description = RuleDescription(
@@ -81,8 +81,7 @@ private extension SelfBindingRule {
 
             if let initializerIdentifier = node.initializer?.value.as(DeclReferenceExprSyntax.self),
                initializerIdentifier.baseName.text == "self" {
-                correctionPositions.append(identifierPattern.positionAfterSkippingLeadingTrivia)
-
+                numberOfCorrections += 1
                 let newPattern = PatternSyntax(
                     identifierPattern
                         .with(\.identifier, identifierPattern.identifier
@@ -92,10 +91,9 @@ private extension SelfBindingRule {
                 return super.visit(node.with(\.pattern, newPattern))
             }
             if node.initializer == nil,
-                      identifierPattern.identifier.text == "self",
-                      configuration.bindIdentifier != "self" {
-                correctionPositions.append(identifierPattern.positionAfterSkippingLeadingTrivia)
-
+               identifierPattern.identifier.text == "self",
+               configuration.bindIdentifier != "self" {
+                numberOfCorrections += 1
                 let newPattern = PatternSyntax(
                     identifierPattern
                         .with(\.identifier, identifierPattern.identifier
