@@ -1,7 +1,8 @@
+import Foundation
 import SwiftSyntax
 
-@SwiftSyntaxRule
-struct SortedEnumCasesRule: OptInRule {
+@SwiftSyntaxRule(optIn: true)
+struct SortedEnumCasesRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
