@@ -1,8 +1,9 @@
+import SwiftBasicFormat
 import SwiftLintCore
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct SuperfluousElseRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct SuperfluousElseRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -69,6 +70,13 @@ struct SuperfluousElseRule: OptInRule {
                     }
                 }
                 """),
+            Example("""
+            if #available(iOS 13, *) {
+                return
+            } else {
+                deprecatedFunction()
+            }
+            """),
         ],
         triggeringExamples: [
             Example("""
@@ -259,14 +267,14 @@ private extension SuperfluousElseRule {
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
         override init(configuration: ConfigurationType, file: SwiftLintFile) {
             super.init(configuration: configuration, file: file)
-            let correctionPositions = Visitor(configuration: configuration, file: file).walk(file: file) {
-                $0.violations.map(\.position)
-            }.filter { !$0.isContainedIn(regions: disabledRegions, locationConverter: locationConverter) }
-            self.correctionPositions.append(contentsOf: correctionPositions)
+            numberOfCorrections += Visitor(configuration: configuration, file: file)
+                .walk(file: file) { $0.violations.map(\.position) }
+                .filter { !$0.isContainedIn(regions: disabledRegions, locationConverter: locationConverter) }
+                .count
         }
 
         override func visitAny(_ node: Syntax) -> Syntax? {
-            correctionPositions.isEmpty ? node : nil // Avoid skipping all `if` expressions in a code block.
+            numberOfCorrections == 0 ? node : nil // Avoid skipping all `if` expressions in a code block.
         }
 
         override func visit(_ list: CodeBlockItemListSyntax) -> CodeBlockItemListSyntax {
@@ -324,10 +332,9 @@ private extension SuperfluousElseRule {
 
 private extension IfExprSyntax {
     var superfluousElse: TokenSyntax? {
-        if elseKeyword == nil {
-            return nil
-        }
-        if !lastStatementExitsScope(in: body) {
+        guard elseKeyword != nil,
+              conditions.onlyElement?.condition.is(AvailabilityConditionSyntax.self) != true,
+              lastStatementExitsScope(in: body) else {
             return nil
         }
         if let parent = parent?.as(IfExprSyntax.self) {
