@@ -54,7 +54,7 @@ extension SwitchCaseAlignmentRule {
             let switchKeywordPosition = node.switchKeyword.positionAfterSkippingLeadingTrivia
             let switchKeywordLocation = locationConverter.location(for: switchKeywordPosition)
 
-            if configuration.ignoreOneLiners && switchKeywordLocation.line == closingBraceLocation.line {
+            if configuration.ignoreOneLiners, switchKeywordLocation.line == closingBraceLocation.line {
                 return
             }
 
@@ -103,7 +103,7 @@ extension SwitchCaseAlignmentRule {
         }
 
         private var indentedCases: [Example] {
-            let violationMarker = indentedCasesOption ? "" : self.violationMarker
+            let violationMarker = indentedCasesOption ? "" : violationMarker
 
             return [
                 Example("""
@@ -144,7 +144,7 @@ extension SwitchCaseAlignmentRule {
         }
 
         private var nonIndentedCases: [Example] {
-            let violationMarker = indentedCasesOption ? self.violationMarker : ""
+            let violationMarker = indentedCasesOption ? violationMarker : ""
 
             return [
                 Example("""
