@@ -1,10 +1,12 @@
 import SwiftLintCore
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct TrailingClosureRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct TrailingClosureRule: Rule {
     var configuration = TrailingClosureConfiguration()
 
+    private static let onlySingleMutedConfig = ["only_single_muted_parameter": true]
+
     static let description = RuleDescription(
         identifier: "trailing_closure",
         name: "Trailing Closure",
@@ -36,6 +38,9 @@ struct TrailingClosureRule: OptInRule {
                 print(i)
             }
             """),
+            Example("foo.reduce(0, combine: { $0 + 1 })", configuration: onlySingleMutedConfig),
+            Example("offsets.sorted(by: { $0.offset < $1.offset })", configuration: onlySingleMutedConfig),
+            Example("foo.something(0, { $0 + 1 })", configuration: onlySingleMutedConfig),
         ],
         triggeringExamples: [
             Example("foo.map(↓{ $0 + 1 })"),
@@ -48,6 +53,7 @@ struct TrailingClosureRule: OptInRule {
                 n.forEach(↓{ print($0) })
             }
             """, excludeFromDocumentation: true),
+            Example("foo.map(↓{ $0 + 1 })", configuration: onlySingleMutedConfig),
         ],
         corrections: [
             Example("foo.map(↓{ $0 + 1 })"):
@@ -79,6 +85,19 @@ struct TrailingClosureRule: OptInRule {
                     f(a: 1,
                     b: 2) { 3 }
                     """),
+            Example("foo.map(↓{ $0 + 1 })", configuration: onlySingleMutedConfig):
+                Example("foo.map { $0 + 1 }", configuration: onlySingleMutedConfig),
+            Example("f(↓{ g(↓{ 1 }) })", configuration: onlySingleMutedConfig):
+                Example("f { g { 1 }}", configuration: onlySingleMutedConfig),
+            Example("""
+                for n in list {
+                    n.forEach(↓{ print($0) })
+                }
+                """, configuration: onlySingleMutedConfig): Example("""
+                    for n in list {
+                        n.forEach { print($0) }
+                    }
+                    """),
             Example("""
                 f(a: 1, // comment
                 b: 2, /* comment */ c: { 3 })
@@ -101,6 +120,19 @@ struct TrailingClosureRule: OptInRule {
                 """): Example("""
                     f(a: 2) /* comment1 */ /* comment2 */ /* comment3 */ { 3 } /* comment4 */
                     """),
+            Example("""
+                let dataSource = RxTableViewSectionedReloadDataSource(
+                    configureCell: { cell in // swiftlint:disable:this trailing_closure
+                        return cell
+                    }
+                )
+                """): Example("""
+                let dataSource = RxTableViewSectionedReloadDataSource(
+                    configureCell: { cell in // swiftlint:disable:this trailing_closure
+                        return cell
+                    }
+                )
+                """),
         ]
     )
 }
@@ -108,7 +140,9 @@ struct TrailingClosureRule: OptInRule {
 private extension TrailingClosureRule {
     final class Visitor: ViolationsSyntaxVisitor<ConfigurationType> {
         override func visitPost(_ node: FunctionCallExprSyntax) {
-            guard node.trailingClosure == nil else { return }
+            guard node.trailingClosure == nil else {
+                return
+            }
 
             if configuration.onlySingleMutedParameter {
                 if let param = node.singleMutedClosureParameter {
@@ -133,17 +167,21 @@ private extension TrailingClosureRule {
 private extension TrailingClosureRule {
     final class Rewriter: ViolationsSyntaxRewriter<ConfigurationType> {
         override func visit(_ node: FunctionCallExprSyntax) -> ExprSyntax {
-            guard node.trailingClosure == nil else { return super.visit(node) }
+            guard node.trailingClosure == nil else {
+                return super.visit(node)
+            }
 
             if configuration.onlySingleMutedParameter {
                 if let param = node.singleMutedClosureParameter,
-                let converted = node.convertToTrailingClosure() {
-                     correctionPositions.append(param.positionAfterSkippingLeadingTrivia)
+                   !isDisabled(atStartPositionOf: param),
+                   let converted = node.convertToTrailingClosure() {
+                    numberOfCorrections += 1
                     return super.visit(converted)
                 }
             } else if let param = node.lastDistinctClosureParameter,
+                      !isDisabled(atStartPositionOf: param),
                       let converted = node.convertToTrailingClosure() {
-                correctionPositions.append(param.positionAfterSkippingLeadingTrivia)
+                numberOfCorrections += 1
                 return super.visit(converted)
             }
             return super.visit(node)
@@ -180,15 +218,13 @@ private extension FunctionCallExprSyntax {
     }
 
     func dropLastArgument() -> Self {
-        self
-            .with(\.arguments, LabeledExprListSyntax(arguments.dropLast()).dropLastTrailingComma())
+        with(\.arguments, LabeledExprListSyntax(arguments.dropLast()).dropLastTrailingComma())
             .dropParensIfEmpty()
     }
 
     func dropParensIfEmpty() -> Self {
         if arguments.isEmpty {
-            self
-                .with(\.rightParen, nil)
+            with(\.rightParen, nil)
                 .with(\.leftParen, nil)
         } else {
             self
@@ -196,7 +232,9 @@ private extension FunctionCallExprSyntax {
     }
 
     func convertToTrailingClosure() -> Self? {
-        guard trailingClosure == nil, let lastDistinctClosureParameter else { return nil }
+        guard let lastDistinctClosureParameter else {
+            return nil
+        }
         let leadingTrivia = lastTriviaInArguments?
             .removingLeadingNewlines()
             .appendingMissingSpace() ?? []
