@@ -1,3 +1,4 @@
+import Foundation
 import SwiftSyntax
 
 @SwiftSyntaxRule(explicitRewriter: true)
@@ -97,7 +98,7 @@ private extension TrailingCommaRule {
 
             switch (lastElement.trailingComma, configuration.mandatoryComma) {
             case (let commaToken?, false):
-                correctionPositions.append(commaToken.positionAfterSkippingLeadingTrivia)
+                numberOfCorrections += 1
                 let newTrailingTrivia = (lastElement.value.trailingTrivia)
                     .appending(trivia: commaToken.leadingTrivia)
                     .appending(trivia: commaToken.trailingTrivia)
@@ -110,7 +111,7 @@ private extension TrailingCommaRule {
                     )
                 return super.visit(newNode)
             case (nil, true) where !locationConverter.isSingleLine(node: node):
-                correctionPositions.append(lastElement.endPositionBeforeTrailingTrivia)
+                numberOfCorrections += 1
                 let newNode = node
                     .with(
                         \.[index],
@@ -132,7 +133,7 @@ private extension TrailingCommaRule {
 
             switch (lastElement.trailingComma, configuration.mandatoryComma) {
             case (let commaToken?, false):
-                correctionPositions.append(commaToken.positionAfterSkippingLeadingTrivia)
+                numberOfCorrections += 1
                 let newNode = node
                     .with(
                         \.[index],
@@ -146,7 +147,7 @@ private extension TrailingCommaRule {
                     )
                 return super.visit(newNode)
             case (nil, true) where !locationConverter.isSingleLine(node: node):
-                correctionPositions.append(lastElement.endPositionBeforeTrailingTrivia)
+                numberOfCorrections += 1
                 let newNode = node
                     .with(
                         \.[index],
@@ -154,7 +155,7 @@ private extension TrailingCommaRule {
                             .with(\.expression, lastElement.expression.with(\.trailingTrivia, []))
                             .with(\.trailingComma, .commaToken())
                             .with(\.trailingTrivia, lastElement.expression.trailingTrivia)
-                )
+                    )
                 return super.visit(newNode)
             case (_, true), (nil, false):
                 return super.visit(node)
