@@ -1,7 +1,7 @@
 import SwiftSyntax
 
-@SwiftSyntaxRule(explicitRewriter: true)
-struct UnneededParenthesesInClosureArgumentRule: OptInRule {
+@SwiftSyntaxRule(explicitRewriter: true, optIn: true)
+struct UnneededParenthesesInClosureArgumentRule: Rule {
     var configuration = SeverityConfiguration<Self>(.warning)
 
     static let description = RuleDescription(
@@ -104,8 +104,7 @@ private extension UnneededParenthesesInClosureArgumentRule {
                 )
             }
 
-            correctionPositions.append(clause.positionAfterSkippingLeadingTrivia)
-
+            numberOfCorrections += 1
             let paramList = ClosureShorthandParameterListSyntax(items).with(\.trailingTrivia, .spaces(1))
             return super.visit(node.with(\.parameterClause, .init(paramList)))
         }
