@@ -1,6 +1,7 @@
 import Foundation
 import SourceKittenFramework
 
+@DisabledWithoutSourceKit
 struct VerticalWhitespaceClosingBracesRule: CorrectableRule, OptInRule {
     var configuration = VerticalWhitespaceClosingBracesConfiguration()
 
@@ -19,7 +20,7 @@ struct VerticalWhitespaceClosingBracesRule: CorrectableRule, OptInRule {
     private let trivialLinePattern = "((?:\\n[ \\t]*)+)(\\n[ \\t)}\\]]*$)"
 
     func validate(file: SwiftLintFile) -> [StyleViolation] {
-        let pattern = configuration.onlyEnforceBeforeTrivialLines ? self.trivialLinePattern : self.pattern
+        let pattern = configuration.onlyEnforceBeforeTrivialLines ? trivialLinePattern : pattern
 
         let patternRegex: NSRegularExpression = regex(pattern)
 
@@ -37,34 +38,24 @@ struct VerticalWhitespaceClosingBracesRule: CorrectableRule, OptInRule {
         }
     }
 
-    func correct(file: SwiftLintFile) -> [Correction] {
-        let pattern = configuration.onlyEnforceBeforeTrivialLines ? self.trivialLinePattern : self.pattern
-
+    func correct(file: SwiftLintFile) -> Int {
+        let pattern = configuration.onlyEnforceBeforeTrivialLines ? trivialLinePattern : pattern
         let violatingRanges = file.ruleEnabled(violatingRanges: file.violatingRanges(for: pattern), for: self)
-        guard violatingRanges.isNotEmpty else { return [] }
-
-        let patternRegex: NSRegularExpression = regex(pattern)
-        let replacementTemplate = "$2"
-        let description = Self.description
-
-        var corrections = [Correction]()
+        guard violatingRanges.isNotEmpty else {
+            return 0
+        }
+        let patternRegex = regex(pattern)
         var fileContents = file.contents
-
         for violationRange in violatingRanges.reversed() {
             fileContents = patternRegex.stringByReplacingMatches(
                 in: fileContents,
                 options: [],
                 range: violationRange,
-                withTemplate: replacementTemplate
+                withTemplate: "$2"
             )
-
-            let location = Location(file: file, characterOffset: violationRange.location)
-            let correction = Correction(ruleDescription: description, location: location)
-            corrections.append(correction)
         }
-
         file.write(fileContents)
-        return corrections
+        return violatingRanges.count
     }
 }
 
