@@ -1,27 +1,45 @@
 import Foundation
 import SourceKittenFramework
 
-private var regexCache = [RegexCacheKey: NSRegularExpression]()
 private let regexCacheLock = NSLock()
+nonisolated(unsafe) private var regexCache = [RegexCacheKey: NSRegularExpression]()
 
-public struct RegularExpression: Hashable, Comparable, ExpressibleByStringLiteral {
+public struct RegularExpression: Hashable, Comparable, ExpressibleByStringLiteral, Sendable {
     public let regex: NSRegularExpression
 
-    public init(pattern: String, options _: NSRegularExpression.Options? = nil) throws {
-        regex = try .cached(pattern: pattern)
+    public init(pattern: String, options: NSRegularExpression.Options? = nil) throws {
+        regex = try .cached(pattern: pattern, options: options)
     }
+
     public init(stringLiteral value: String) {
         // swiftlint:disable:next force_try
         try! self.init(pattern: value)
     }
 
-    var pattern: String { regex.pattern }
+    package var pattern: String { regex.pattern }
 
     var numberOfCaptureGroups: Int { regex.numberOfCaptureGroups }
 
     public static func < (lhs: Self, rhs: Self) -> Bool {
         lhs.pattern < rhs.pattern
     }
+
+    /// Creates a `RegularExpression` from a pattern and options.
+    ///
+    /// - Parameters:
+    ///   - pattern: The pattern to compile into a regular expression.
+    ///   - options: The options to use when compiling the regular expression.
+    ///   - ruleID: The identifier of the rule that is using this regular expression in its configuration.
+    /// - Returns: A `RegularExpression` instance.
+    public static func from(pattern: String,
+                            options: NSRegularExpression.Options? = nil,
+                            for ruleID: String) throws(Issue) -> Self {
+        do {
+            return try Self(pattern: pattern, options: options)
+        } catch {
+            throw .invalidRegexPattern(ruleID: ruleID, pattern: pattern)
+        }
+    }
 }
 
 private struct RegexCacheKey: Hashable {
