@@ -1,5 +1,6 @@
-import Dispatch
-import Foundation
+@preconcurrency import Dispatch
+@preconcurrency import Foundation
+import SourceKittenFramework
 
 private let outputQueue: DispatchQueue = {
     let queue = DispatchQueue(
