@@ -55,8 +55,8 @@ public extension String {
                                limitedBy: utf16.endIndex) ?? utf16.endIndex
 
         guard let fromIndex = Index(from16, within: self),
-            let toIndex = Index(to16, within: self) else {
-                return nil
+              let toIndex = Index(to16, within: self) else {
+            return nil
         }
 
         return fromIndex..<toIndex
@@ -68,13 +68,16 @@ public extension String {
 
     /// Returns a new string, converting the path to a canonical absolute path.
     ///
+    /// > Important: This method might use an incorrect working directory internally. This can cause test failures
+    /// in Bazel builds but does not seem to cause trouble in production.
+    ///
     /// - returns: A new `String`.
     func absolutePathStandardized() -> String {
-        bridge().absolutePathRepresentation().bridge().standardizingPath
+        URL(fileURLWithPath: bridge().standardizingPath.absolutePathRepresentation()).filepath
     }
 
     var isFile: Bool {
-        if self.isEmpty {
+        if isEmpty {
             return false
         }
         var isDirectoryObjC: ObjCBool = false
@@ -88,9 +91,7 @@ public extension String {
     /// - Parameter character: Character to count
     /// - Returns: Number of times `character` occurs in `self`
     func countOccurrences(of character: Character) -> Int {
-        self.reduce(0, {
-            $1 == character ? $0 + 1 : $0
-        })
+        reduce(0) { $1 == character ? $0 + 1 : $0 }
     }
 
     /// If self is a path, this method can be used to get a path expression relative to a root directory
@@ -106,7 +107,7 @@ public extension String {
         while true {
             let sharedRootDir = rootDirComps.joined(separator: "/")
             if normalizedSelf == sharedRootDir || normalizedSelf.hasPrefix(sharedRootDir + "/") {
-                let path = (0 ..< rootDirCompsCount - rootDirComps.count).map { _ in "/.." }.flatMap { $0 }
+                let path = (0 ..< rootDirCompsCount - rootDirComps.count).map { _ in "/.." }.flatMap(\.self)
                     + String(normalizedSelf.dropFirst(sharedRootDir.count))
                 return String(path.dropFirst()) // Remove leading '/'
             }
@@ -119,13 +120,40 @@ public extension String {
         return String(dropFirst(prefix.count))
     }
 
-    func indent(by spaces: Int) -> String {
-        components(separatedBy: "\n")
-            .map { String(repeating: " ", count: spaces) + $0 }
-            .joined(separator: "\n")
+    func indent(by spaces: Int, skipFirst: Bool = false, skipEmptyLines: Bool = true) -> String {
+        let lines = components(separatedBy: "\n")
+        if skipFirst, let firstLine = lines.first {
+            return firstLine + "\n" + lines.dropFirst().indent(by: spaces, skipEmptyLines: skipEmptyLines)
+        }
+        return lines.indent(by: spaces, skipEmptyLines: skipEmptyLines)
     }
 
     func linesPrefixed(with prefix: Self) -> Self {
         split(separator: "\n").joined(separator: "\n\(prefix)")
     }
+
+    func characterPosition(of utf8Offset: Int) -> Int? {
+        guard utf8Offset != 0 else {
+            return 0
+        }
+        guard utf8Offset > 0, utf8Offset < lengthOfBytes(using: .utf8) else {
+            return nil
+        }
+        for (offset, index) in indices.enumerated() where self[...index].lengthOfBytes(using: .utf8) == utf8Offset {
+            return offset + 1
+        }
+        return nil
+    }
+}
+
+private extension Sequence where Element == String {
+    func indent(by spaces: Int, skipEmptyLines: Bool = true) -> String {
+        map { line in
+            if skipEmptyLines, line.isEmpty {
+                return line
+            }
+            return String(repeating: " ", count: spaces) + line
+        }
+        .joined(separator: "\n")
+    }
 }
