@@ -10,7 +10,7 @@ public extension SwiftDeclarationAttributeKind {
         ]
     }
 
-    enum ModifierGroup: String, CustomDebugStringConvertible {
+    enum ModifierGroup: String, CustomDebugStringConvertible, Sendable {
         case `override`
         case acl
         case setterACL
@@ -22,12 +22,13 @@ public extension SwiftDeclarationAttributeKind {
         case `convenience`
         case `lazy`
         case `dynamic`
+        case isolation
         case atPrefixed
 
         public init?(rawAttribute: String) {
             let allModifierGroups: Set<SwiftDeclarationAttributeKind.ModifierGroup> = [
                 .acl, .setterACL, .mutators, .override, .owned, .atPrefixed, .dynamic, .final, .typeMethods,
-                .required, .convenience, .lazy,
+                .required, .convenience, .lazy, .isolation,
             ]
             let modifierGroup = allModifierGroups.first {
                 $0.swiftDeclarationAttributeKinds.contains(where: { $0.rawValue == rawAttribute })
@@ -79,12 +80,15 @@ public extension SwiftDeclarationAttributeKind {
                 return [.lazy]
             case .dynamic:
                 return [.dynamic]
+            case .isolation:
+                return [.nonisolated]
             case .atPrefixed:
                 return [
                     .objc,
                     .nonobjc,
                     .objcMembers,
                     .ibaction,
+                    .ibsegueaction,
                     .iboutlet,
                     .ibdesignable,
                     .ibinspectable,
@@ -95,7 +99,7 @@ public extension SwiftDeclarationAttributeKind {
         }
 
         public var debugDescription: String {
-            self.rawValue
+            rawValue
         }
     }
 }
