@@ -1,15 +1,6 @@
-import SourceKittenFramework
+@preconcurrency import SourceKittenFramework
 
 public extension SwiftDeclarationKind {
-    static let variableKinds: Set<SwiftDeclarationKind> = [
-        .varClass,
-        .varGlobal,
-        .varInstance,
-        .varLocal,
-        .varParameter,
-        .varStatic,
-    ]
-
     static let functionKinds: Set<SwiftDeclarationKind> = [
         .functionAccessorAddress,
         .functionAccessorDidset,
@@ -34,12 +25,4 @@ public extension SwiftDeclarationKind {
         .associatedtype,
         .enum,
     ]
-
-    static let extensionKinds: Set<SwiftDeclarationKind> = [
-        .extension,
-        .extensionClass,
-        .extensionEnum,
-        .extensionProtocol,
-        .extensionStruct,
-    ]
 }
