@@ -3,6 +3,7 @@ import Darwin
 #endif
 import Foundation
 import SourceKittenFramework
+import SwiftDiagnostics
 import SwiftIDEUtils
 import SwiftOperators
 import SwiftParser
@@ -46,24 +47,27 @@ private let syntaxMapCache = Cache { file in
     responseCache.get(file).map { SwiftLintSyntaxMap(value: SyntaxMap(sourceKitResponse: $0)) }
 }
 private let syntaxClassificationsCache = Cache { $0.syntaxTree.classifications }
-private let syntaxKindsByLinesCache = Cache { $0.syntaxKindsByLine() }
-private let syntaxTokensByLinesCache = Cache { $0.syntaxTokensByLine() }
 private let linesWithTokensCache = Cache { $0.computeLinesWithTokens() }
+private let swiftSyntaxTokensCache = Cache { file -> [SwiftLintSyntaxToken]? in
+    // Use SwiftSyntaxKindBridge to derive SourceKitten-compatible tokens from SwiftSyntax
+    SwiftSyntaxKindBridge.sourceKittenSyntaxKinds(for: file)
+}
+private let commentLinesCache = Cache { CommentLinesVisitor.commentLines(in: $0) }
+private let emptyLinesCache = Cache { EmptyLinesVisitor.emptyLines(in: $0) }
 
-internal typealias AssertHandler = () -> Void
+package typealias AssertHandler = () -> Void
 // Re-enable once all parser diagnostics in tests have been addressed.
 // https://github.com/realm/SwiftLint/issues/3348
-package var parserDiagnosticsDisabledForTests = false
+@TaskLocal package var parserDiagnosticsDisabledForTests = false
 
-private let assertHandlers = [FileCacheKey: AssertHandler]()
-private let assertHandlerCache = Cache { file in assertHandlers[file.cacheKey] }
+private let assertHandlerCache = Cache { (_: SwiftLintFile) -> AssertHandler? in nil }
 
-private class Cache<T> {
-    private var values = [FileCacheKey: T]()
-    private let factory: (SwiftLintFile) -> T
+private final class Cache<T>: Sendable {
+    nonisolated(unsafe) private var values = [FileCacheKey: T]()
+    private let factory: @Sendable (SwiftLintFile) -> T
     private let lock = PlatformLock()
 
-    fileprivate init(_ factory: @escaping (SwiftLintFile) -> T) {
+    fileprivate init(_ factory: @escaping @Sendable (SwiftLintFile) -> T) {
         self.factory = factory
     }
 
@@ -114,7 +118,7 @@ extension SwiftLintFile {
         }
     }
 
-    internal var assertHandler: AssertHandler? {
+    package var assertHandler: AssertHandler? {
         get {
             assertHandlerCache.get(self)
         }
@@ -123,9 +127,9 @@ extension SwiftLintFile {
         }
     }
 
-    public var parserDiagnostics: [String]? {
+    public var parserDiagnostics: [String] {
         if parserDiagnosticsDisabledForTests {
-            return nil
+            return []
         }
 
         return ParseDiagnosticsGenerator.diagnostics(for: syntaxTree)
@@ -169,27 +173,12 @@ extension SwiftLintFile {
 
     public var invalidCommands: [Command] { commandsCache.get(self).filter { !$0.isValid } }
 
-    public var syntaxTokensByLines: [[SwiftLintSyntaxToken]] {
-        guard let syntaxTokensByLines = syntaxTokensByLinesCache.get(self) else {
-            if let handler = assertHandler {
-                handler()
-                return []
-            }
-            queuedFatalError("Never call this for file that sourcekitd fails.")
-        }
-        return syntaxTokensByLines
+    public var swiftSyntaxDerivedSourceKittenTokens: [SwiftLintSyntaxToken]? {
+        swiftSyntaxTokensCache.get(self)
     }
 
-    public var syntaxKindsByLines: [[SourceKittenFramework.SyntaxKind]] {
-        guard let syntaxKindsByLines = syntaxKindsByLinesCache.get(self) else {
-            if let handler = assertHandler {
-                handler()
-                return []
-            }
-            queuedFatalError("Never call this for file that sourcekitd fails.")
-        }
-        return syntaxKindsByLines
-    }
+    public var commentLines: Set<Int> { commentLinesCache.get(self) }
+    public var emptyLines: Set<Int> { emptyLinesCache.get(self) }
 
     /// Invalidates all cached data for this file.
     public func invalidateCache() {
@@ -199,13 +188,14 @@ extension SwiftLintFile {
         structureDictionaryCache.invalidate(self)
         syntaxClassificationsCache.invalidate(self)
         syntaxMapCache.invalidate(self)
-        syntaxTokensByLinesCache.invalidate(self)
-        syntaxKindsByLinesCache.invalidate(self)
+        swiftSyntaxTokensCache.invalidate(self)
         syntaxTreeCache.invalidate(self)
         foldedSyntaxTreeCache.invalidate(self)
         locationConverterCache.invalidate(self)
         commandsCache.invalidate(self)
         linesWithTokensCache.invalidate(self)
+        commentLinesCache.invalidate(self)
+        emptyLinesCache.invalidate(self)
     }
 
     package static func clearCaches() {
@@ -214,19 +204,20 @@ extension SwiftLintFile {
         structureDictionaryCache.clear()
         syntaxClassificationsCache.clear()
         syntaxMapCache.clear()
-        syntaxTokensByLinesCache.clear()
-        syntaxKindsByLinesCache.clear()
+        swiftSyntaxTokensCache.clear()
         syntaxTreeCache.clear()
         foldedSyntaxTreeCache.clear()
         locationConverterCache.clear()
         commandsCache.clear()
         linesWithTokensCache.clear()
+        commentLinesCache.clear()
+        emptyLinesCache.clear()
     }
 }
 
-private final class PlatformLock {
+private final class PlatformLock: Sendable {
 #if canImport(Darwin)
-    private let primitiveLock: UnsafeMutablePointer<os_unfair_lock>
+    nonisolated(unsafe) private let primitiveLock: UnsafeMutablePointer<os_unfair_lock>
 #else
     private let primitiveLock = NSLock()
 #endif
