@@ -36,7 +36,7 @@ extension SwiftLintFile {
                 break
             }
 
-            let start = Location(file: path, line: command.line, character: command.character)
+            let start = Location(file: path, line: command.line, character: command.range?.upperBound)
             let end = endOf(next: nextCommand)
             guard start < end else { continue }
             var didSetRegion = false
@@ -67,19 +67,19 @@ extension SwiftLintFile {
         let rangeEnd = Location(file: self, characterOffset: NSMaxRange(range))
         return commands
             .filter { command in
-                let commandLocation = Location(file: path, line: command.line, character: command.character)
+                let commandLocation = Location(file: path, line: command.line, character: command.range?.upperBound)
                 return rangeStart <= commandLocation && commandLocation <= rangeEnd
             }
             .flatMap { $0.expand() }
     }
 
-    fileprivate func endOf(next command: Command?) -> Location {
+    private func endOf(next command: Command?) -> Location {
         guard let nextCommand = command else {
             return Location(file: path, line: .max, character: .max)
         }
         let nextLine: Int
         let nextCharacter: Int?
-        if let nextCommandCharacter = nextCommand.character {
+        if let nextCommandCharacter = nextCommand.range?.upperBound {
             nextLine = nextCommand.line
             if nextCommandCharacter > 0 {
                 nextCharacter = nextCommandCharacter - 1
@@ -99,95 +99,17 @@ extension SwiftLintFile {
             .map(\.0)
     }
 
-    public func matchesAndTokens(matching pattern: String,
-                                 range: NSRange? = nil) -> [(NSTextCheckingResult, [SwiftLintSyntaxToken])] {
+    public func match(pattern: String, range: NSRange? = nil, captureGroup: Int = 0) -> [(NSRange, [SyntaxKind])] {
         let contents = stringView
         let range = range ?? contents.range
         let syntax = syntaxMap
         return regex(pattern).matches(in: contents, options: [], range: range).compactMap { match in
-            let matchByteRange = contents.NSRangeToByteRange(start: match.range.location, length: match.range.length)
-            return matchByteRange.map { (match, syntax.tokens(inByteRange: $0)) }
+            let matchByteRange = contents.NSRangeToByteRange(
+                start: match.range.location, length: match.range.length)
+            return matchByteRange.map { (match.range(at: captureGroup), syntax.tokens(inByteRange: $0).kinds) }
         }
     }
 
-    public func matchesAndSyntaxKinds(matching pattern: String,
-                                      range: NSRange? = nil) -> [(NSTextCheckingResult, [SyntaxKind])] {
-        matchesAndTokens(matching: pattern, range: range).map { textCheckingResult, tokens in
-            (textCheckingResult, tokens.kinds)
-        }
-    }
-
-    public func rangesAndTokens(matching pattern: String,
-                                range: NSRange? = nil) -> [(NSRange, [SwiftLintSyntaxToken])] {
-        matchesAndTokens(matching: pattern, range: range).map { ($0.0.range, $0.1) }
-    }
-
-    public func match(pattern: String, range: NSRange? = nil, captureGroup: Int = 0) -> [(NSRange, [SyntaxKind])] {
-        matchesAndSyntaxKinds(matching: pattern, range: range).map { textCheckingResult, syntaxKinds in
-            (textCheckingResult.range(at: captureGroup), syntaxKinds)
-        }
-    }
-
-    public func swiftDeclarationKindsByLine() -> [[SwiftDeclarationKind]]? {
-        if sourcekitdFailed {
-            return nil
-        }
-        var results = [[SwiftDeclarationKind]](repeating: [], count: lines.count + 1)
-        var lineIterator = lines.makeIterator()
-        var structureIterator = structureDictionary.kinds().makeIterator()
-        var maybeLine = lineIterator.next()
-        var maybeStructure = structureIterator.next()
-        while let line = maybeLine, let structure = maybeStructure {
-            if line.byteRange.contains(structure.byteRange.location),
-               let swiftDeclarationKind = SwiftDeclarationKind(rawValue: structure.kind) {
-                results[line.index].append(swiftDeclarationKind)
-            }
-            if structure.byteRange.location >= line.byteRange.upperBound {
-                maybeLine = lineIterator.next()
-            } else {
-                maybeStructure = structureIterator.next()
-            }
-        }
-        return results
-    }
-
-    public func syntaxTokensByLine() -> [[SwiftLintSyntaxToken]]? {
-        if sourcekitdFailed {
-            return nil
-        }
-        var results = [[SwiftLintSyntaxToken]](repeating: [], count: lines.count + 1)
-        var tokenGenerator = syntaxMap.tokens.makeIterator()
-        var lineGenerator = lines.makeIterator()
-        var maybeLine = lineGenerator.next()
-        var maybeToken = tokenGenerator.next()
-        while let line = maybeLine, let token = maybeToken {
-            let tokenRange = token.range
-            if line.byteRange.contains(token.offset) ||
-                tokenRange.contains(line.byteRange.location) {
-                    results[line.index].append(token)
-            }
-            let tokenEnd = tokenRange.upperBound
-            let lineEnd = line.byteRange.upperBound
-            if tokenEnd < lineEnd {
-                maybeToken = tokenGenerator.next()
-            } else if tokenEnd > lineEnd {
-                maybeLine = lineGenerator.next()
-            } else {
-                maybeLine = lineGenerator.next()
-                maybeToken = tokenGenerator.next()
-            }
-        }
-        return results
-    }
-
-    public func syntaxKindsByLine() -> [[SyntaxKind]]? {
-        guard !sourcekitdFailed, let tokens = syntaxTokensByLine() else {
-            return nil
-        }
-
-        return tokens.map(\.kinds)
-    }
-
     /**
      This function returns only matches that are not contained in a syntax kind
      specified.
@@ -208,23 +130,6 @@ extension SwiftLintFile {
             .map(\.0)
     }
 
-    public typealias MatchMapping = (NSTextCheckingResult) -> NSRange
-
-    public func match(pattern: String,
-                      range: NSRange? = nil,
-                      excludingSyntaxKinds: Set<SyntaxKind>,
-                      excludingPattern: String,
-                      exclusionMapping: MatchMapping = \.range) -> [NSRange] {
-        let matches = match(pattern: pattern, excludingSyntaxKinds: excludingSyntaxKinds)
-        if matches.isEmpty {
-            return []
-        }
-        let range = range ?? stringView.range
-        let exclusionRanges = regex(excludingPattern).matches(in: stringView, options: [],
-                                                              range: range).map(exclusionMapping)
-        return matches.filter { !$0.intersects(exclusionRanges) }
-    }
-
     public func append(_ string: String) {
         guard string.isNotEmpty else {
             return
@@ -237,7 +142,7 @@ extension SwiftLintFile {
             queuedFatalError("can't encode '\(string)' with UTF8")
         }
         guard let path, let fileHandle = FileHandle(forWritingAtPath: path) else {
-            queuedFatalError("can't write to path '\(String(describing: self.path))'")
+            queuedFatalError("can't write to path '\(String(describing: path))'")
         }
         _ = fileHandle.seekToEndOfFile()
         fileHandle.write(stringData)
@@ -282,15 +187,6 @@ extension SwiftLintFile {
         ruleEnabled(violatingRanges: [violatingRange], for: rule).first
     }
 
-    public func isACL(token: SwiftLintSyntaxToken) -> Bool {
-        guard token.kind == .attributeBuiltin else {
-            return false
-        }
-
-        let aclString = contents(for: token)
-        return aclString.flatMap(AccessControlLevel.init(description:)) != nil
-    }
-
     public func contents(for token: SwiftLintSyntaxToken) -> String? {
         stringView.substringWithByteRange(token.range)
     }
