@@ -1,6 +1,9 @@
+import Foundation
 import SourceKittenFramework
 import SwiftSyntax
 
+// swiftlint:disable file_length
+
 // workaround for https://bugs.swift.org/browse/SR-10121 so we can use `Self` in a closure
 public protocol SwiftLintSyntaxVisitor: SyntaxVisitor {}
 extension SyntaxVisitor: SwiftLintSyntaxVisitor {}
@@ -41,9 +44,12 @@ public extension AbsolutePosition {
     }
 }
 
-public extension ByteSourceRange {
+public extension Range<AbsolutePosition> {
     func toSourceKittenByteRange() -> ByteRange {
-        ByteRange(location: ByteCount(offset), length: ByteCount(length))
+        ByteRange(
+            location: ByteCount(lowerBound),
+            length: ByteCount(upperBound.utf8Offset) - ByteCount(lowerBound.utf8Offset)
+        )
     }
 }
 
@@ -59,12 +65,12 @@ public extension ClassDeclSyntax {
 
 public extension ExprSyntax {
     var asFunctionCall: FunctionCallExprSyntax? {
-        if let functionCall = self.as(FunctionCallExprSyntax.self) {
+        if let functionCall = `as`(FunctionCallExprSyntax.self) {
             return functionCall
         }
-        if let tuple = self.as(TupleExprSyntax.self),
-                  let firstElement = tuple.elements.onlyElement,
-                  let functionCall = firstElement.expression.as(FunctionCallExprSyntax.self) {
+        if let tuple = `as`(TupleExprSyntax.self),
+           let firstElement = tuple.elements.onlyElement,
+           let functionCall = firstElement.expression.as(FunctionCallExprSyntax.self) {
             return functionCall
         }
         return nil
@@ -125,6 +131,10 @@ public extension DeclModifierSyntax {
             return nil
         }
     }
+
+    var isStaticOrClass: Bool {
+        name.tokenKind == .keyword(.static) || name.tokenKind == .keyword(.class)
+    }
 }
 
 public extension AttributeSyntax {
@@ -184,6 +194,19 @@ public extension EnumDeclSyntax {
             return rawValueTypes.contains(identifier)
         }
     }
+
+    /// True if this enum is a `CodingKey`. For that, it has to be named `CodingKeys`
+    /// and must conform to the `CodingKey` protocol.
+    var definesCodingKeys: Bool {
+        guard let inheritedTypeCollection = inheritanceClause?.inheritedTypes,
+              name.text == "CodingKeys" else {
+            return false
+        }
+
+        return inheritedTypeCollection.contains { element in
+            element.type.as(IdentifierTypeSyntax.self)?.name.text == "CodingKey"
+        }
+    }
 }
 
 public extension FunctionDeclSyntax {
@@ -193,7 +216,7 @@ public extension FunctionDeclSyntax {
 
     /// Returns the signature including arguments, e.g "setEditing(_:animated:)"
     var resolvedName: String {
-        var name = self.name.text
+        var name = name.text
         name += "("
 
         let params = signature.parameterClause.parameters.compactMap { param in
@@ -341,7 +364,7 @@ public extension DeclReferenceExprSyntax {
 
 public extension ClosureCaptureSyntax {
     var capturesSelf: Bool {
-        expression.as(DeclReferenceExprSyntax.self)?.isSelf == true
+        name.text == "self"
     }
 
     var capturesWeakly: Bool {
@@ -349,6 +372,18 @@ public extension ClosureCaptureSyntax {
     }
 }
 
+public extension TypeSyntax {
+    var isOptionalType: Bool {
+        if `is`(OptionalTypeSyntax.self) {
+            return true
+        }
+        if let type = `as`(IdentifierTypeSyntax.self) {
+            return type.name.text == "Optional" && type.genericArgumentClause?.arguments.count == 1
+        }
+        return false
+    }
+}
+
 private extension String {
     var isZero: Bool {
         if self == "0" { // fast path
