@@ -1,6 +1,8 @@
 /// A rule configuration that allows to disable (`off`) an option of a rule or specify its severity level in which
 /// case it's active.
-public struct ChildOptionSeverityConfiguration<Parent: Rule>: RuleConfiguration, AcceptableByConfigurationElement {
+public struct ChildOptionSeverityConfiguration<Parent: Rule>: RuleConfiguration,
+                                                              AcceptableByConfigurationElement,
+                                                              Sendable {
     /// Configuration with a warning severity.
     public static var error: Self { Self(optionSeverity: .error) }
     /// Configuration with an error severity.
@@ -20,10 +22,10 @@ public struct ChildOptionSeverityConfiguration<Parent: Rule>: RuleConfiguration,
         ViolationSeverity(rawValue: optionSeverity.rawValue)
     }
 
-    public mutating func apply(configuration: Any) throws {
+    public mutating func apply(configuration: Any) throws(Issue) {
         guard let configString = configuration as? String,
-            let optionSeverity = ChildOptionSeverity(rawValue: configString.lowercased()) else {
-            throw Issue.invalidConfiguration(ruleID: Parent.description.identifier)
+              let optionSeverity = ChildOptionSeverity(rawValue: configString.lowercased()) else {
+            throw .invalidConfiguration(ruleID: Parent.identifier)
         }
         self.optionSeverity = optionSeverity
     }
