@@ -1,3 +1,5 @@
+import Foundation
+
 /// Captures code and context information for an example of a triggering or
 /// non-triggering style
 public struct Example: Sendable {
@@ -26,6 +28,8 @@ public struct Example: Sendable {
     package private(set) var testDisableCommand: Bool
     /// Whether the example should be tested on Linux
     public private(set) var testOnLinux: Bool
+    /// Whether the example should be tested on Windows
+    public private(set) var testOnWindows: Bool
     /// The path to the file where the example was created
     public private(set) var file: StaticString
     /// The line in the file where the example was created
@@ -37,7 +41,7 @@ public struct Example: Sendable {
     /// why a rule is applied and where not. Complex examples with rarely used language constructs or
     /// pathological use cases which are indeed important to test but not helpful for understanding can be
     /// hidden from the documentation with this option.
-    let excludeFromDocumentation: Bool
+    package let excludeFromDocumentation: Bool
 
     /// Specifies whether the test example should be the only example run during the current test case execution.
     package var isFocused: Bool
@@ -66,6 +70,7 @@ public extension Example {
          testWrappingInString: Bool = true,
          testDisableCommand: Bool = true,
          testOnLinux: Bool = true,
+         testOnWindows: Bool = true,
          file: StaticString = #filePath,
          line: UInt = #line,
          excludeFromDocumentation: Bool = false) {
@@ -73,6 +78,7 @@ public extension Example {
         self.configuration = configuration
         self.testMultiByteOffsets = testMultiByteOffsets
         self.testOnLinux = testOnLinux
+        self.testOnWindows = testOnWindows
         self.file = file
         self.line = line
         self.excludeFromDocumentation = excludeFromDocumentation
@@ -134,12 +140,15 @@ extension Example: Hashable {
         // Ignoring file/line metadata because two Examples could represent
         // the same idea, but captured at two different points in the code
         lhs.code == rhs.code
+            && lhs.configuration?.mapValues(String.init(describing:))
+                == rhs.configuration?.mapValues(String.init(describing:))
     }
 
     public func hash(into hasher: inout Hasher) {
         // Ignoring file/line metadata because two Examples could represent
         // the same idea, but captured at two different points in the code
         hasher.combine(code)
+        hasher.combine(configuration?.mapValues(String.init(describing:)))
     }
 }
 
