@@ -3,7 +3,10 @@ import Foundation
 /// All possible SwiftLint issues which are printed as warnings by default.
 public enum Issue: LocalizedError, Equatable {
     /// The configuration didn't match internal expectations.
-    case invalidConfiguration(ruleID: String)
+    case invalidConfiguration(ruleID: String, message: String? = nil)
+
+    /// Issued when a regular expression pattern is invalid.
+    case invalidRegexPattern(ruleID: String, pattern: String)
 
     /// Issued when an option is deprecated. Suggests an alternative optionally.
     case deprecatedConfigurationOption(ruleID: String, key: String, alternative: String? = nil)
@@ -20,6 +23,10 @@ public enum Issue: LocalizedError, Equatable {
     /// Some configuration keys are invalid.
     case invalidConfigurationKeys(ruleID: String, keys: Set<String>)
 
+    /// The configuration is inconsistent, that is options are mutually exclusive or one drives other values
+    /// irrelevant.
+    case inconsistentConfiguration(ruleID: String, message: String)
+
     /// Used rule IDs are invalid.
     case invalidRuleIDs(Set<String>)
 
@@ -75,7 +82,9 @@ public enum Issue: LocalizedError, Equatable {
     case baselineNotReadable(path: String)
 
     /// Flag to enable warnings for deprecations being printed to the console. Printing is enabled by default.
-    public static var printDeprecationWarnings = true
+    package nonisolated(unsafe) static var printDeprecationWarnings = true
+
+    @TaskLocal private static var printQueueContinuation: AsyncStream<String>.Continuation?
 
     /// Hook used to capture all messages normally printed to stdout and return them back to the caller.
     ///
@@ -84,32 +93,30 @@ public enum Issue: LocalizedError, Equatable {
     /// - parameter runner: The code to run. Messages printed during the execution are collected.
     ///
     /// - returns: The collected messages produced while running the code in the runner.
-    static func captureConsole(runner: () throws -> Void) rethrows -> String {
-        var console = ""
-        messageConsumer = { console += (console.isEmpty ? "" : "\n") + $0 }
-        defer { messageConsumer = nil }
-        try runner()
-        return console
+    @MainActor
+    static func captureConsole(runner: @Sendable () throws -> Void) async rethrows -> String {
+        let (stream, continuation) = AsyncStream.makeStream(of: String.self)
+        try $printQueueContinuation.withValue(continuation, operation: runner)
+        continuation.finish()
+        return await stream.reduce(into: "") { @Sendable in $0 += $0.isEmpty ? $1 : "\n\($1)" }
     }
 
-    private static var messageConsumer: ((String) -> Void)?
-
     /// Wraps any `Error` into a `SwiftLintError.genericWarning` if it is not already a `SwiftLintError`.
     ///
     /// - parameter error: Any `Error`.
     ///
     /// - returns: A `SwiftLintError.genericWarning` containing the message of the `error` argument.
-    static func wrap(error: some Error) -> Self {
+    package static func wrap(error: some Error) -> Self {
         error as? Self ?? Self.genericWarning(error.localizedDescription)
     }
 
     /// Make this issue an error.
-    var asError: Self {
+    package var asError: Self {
         Self.genericError(message)
     }
 
     /// The issues description which is ready to be printed to the console.
-    var errorDescription: String {
+    public var errorDescription: String? {
         switch self {
         case .genericError:
             return "error: \(message)"
@@ -125,17 +132,17 @@ public enum Issue: LocalizedError, Equatable {
         if case .ruleDeprecated = self, !Self.printDeprecationWarnings {
             return
         }
-        if let consumer = Self.messageConsumer {
-            consumer(errorDescription)
-        } else {
-            queuedPrintError(errorDescription)
-        }
+        Self.printQueueContinuation?.yield(localizedDescription)
+        queuedPrintError(localizedDescription)
     }
 
     private var message: String {
         switch self {
-        case let .invalidConfiguration(id):
-            return "Invalid configuration for '\(id)' rule. Falling back to default."
+        case let .invalidConfiguration(id, message):
+            let message = if let message { ": \(message)" } else { "." }
+            return "Invalid configuration for '\(id)' rule\(message) Falling back to default."
+        case let .invalidRegexPattern(id, pattern):
+            return "Invalid regular expression pattern '\(pattern)' used to configure '\(id)' rule."
         case let .deprecatedConfigurationOption(id, key, alternative):
             let baseMessage = "Configuration option '\(key)' in '\(id)' rule is deprecated."
             if let alternative {
@@ -150,22 +157,20 @@ public enum Issue: LocalizedError, Equatable {
             return "'\(old)' has been renamed to '\(new)' and will be completely removed in a future release."
         case let .invalidConfigurationKeys(id, keys):
             return "Configuration for '\(id)' rule contains the invalid key(s) \(keys.formatted)."
+        case let .inconsistentConfiguration(id, message):
+            return "Inconsistent configuration for '\(id)' rule: \(message)"
         case let .invalidRuleIDs(ruleIDs):
             return "The key(s) \(ruleIDs.formatted) used as rule identifier(s) is/are invalid."
         case let .ruleNotPresentInOnlyRules(id):
-            return "Found a configuration for '\(id)' rule, but it is not present in " +
-                   "'\(Configuration.Key.onlyRules.rawValue)'."
+            return "Found a configuration for '\(id)' rule, but it is not present in 'only_rules'."
         case let .ruleDisabledInDisabledRules(id):
-            return "Found a configuration for '\(id)' rule, but it is disabled in " +
-                   "'\(Configuration.Key.disabledRules.rawValue)'."
+            return "Found a configuration for '\(id)' rule, but it is disabled in 'disabled_rules'."
         case let .ruleDisabledInParentConfiguration(id):
             return "Found a configuration for '\(id)' rule, but it is disabled in a parent configuration."
         case let .ruleNotEnabledInOptInRules(id):
-            return "Found a configuration for '\(id)' rule, but it is not enabled in " +
-                   "'\(Configuration.Key.optInRules.rawValue)'."
+            return "Found a configuration for '\(id)' rule, but it is not enabled in 'opt_in_rules'."
         case let .ruleNotEnabledInParentOnlyRules(id):
-            return "Found a configuration for '\(id)' rule, but it is not present in the parent's " +
-                   "'\(Configuration.Key.onlyRules.rawValue)'."
+            return "Found a configuration for '\(id)' rule, but it is not present in the parent's 'only_rules'."
         case let .genericWarning(message), let .genericError(message):
             return message
         case let .ruleDeprecated(id):
