@@ -4,6 +4,9 @@ import Foundation
 
 /// A type that can be converted into a human-readable representation.
 public protocol Documentable {
+    /// Indicate if the item has some content that is useful to document.
+    var hasContent: Bool { get }
+
     /// Convert an object to Markdown.
     ///
     /// - Returns: A Markdown string describing the object.
@@ -14,9 +17,6 @@ public protocol Documentable {
     /// - Returns: A "one liner" describing the object.
     func oneLiner() -> String
 
-    /// Indicate if the item has some content that is useful to document.
-    var hasContent: Bool { get }
-
     /// Convert an object to YAML as used in `.swiftlint.yml`.
     ///
     /// - Returns: A YAML snippet that can be used in configuration files.
@@ -24,7 +24,7 @@ public protocol Documentable {
 }
 
 /// Description of a rule configuration.
-public struct RuleConfigurationDescription: Equatable {
+public struct RuleConfigurationDescription: Equatable, Sendable {
     fileprivate let options: [RuleConfigurationOption]
 
     fileprivate init(options: [RuleConfigurationOption], exclusiveOptions: Set<String> = []) {
@@ -53,16 +53,14 @@ public struct RuleConfigurationDescription: Equatable {
             return Self(options: customDescription.options, exclusiveOptions: exclusiveOptions)
         }
         let options: [RuleConfigurationOption] = Mirror(reflecting: configuration).children
-            .compactMap { child -> Self? in
+            .flatMap { child in
                 // Property wrappers have names prefixed by an underscore.
-                guard let codingKey = child.label, codingKey.starts(with: "_") else {
-                    return nil
+                if child.label?.starts(with: "_") == true,
+                   let element = child.value as? any AnyConfigurationElement {
+                    return element.description.options
                 }
-                guard let element = child.value as? any AnyConfigurationElement else {
-                    return nil
-                }
-                return element.description
-            }.flatMap(\.options)
+                return []
+            }
         guard options.isNotEmpty else {
             queuedFatalError(
                 """
@@ -124,7 +122,7 @@ extension RuleConfigurationDescription: Documentable {
 }
 
 /// A single option of a ``RuleConfigurationDescription``.
-public struct RuleConfigurationOption: Equatable {
+public struct RuleConfigurationOption: Equatable, Sendable {
     /// An option serving as a marker for an empty configuration description.
     public static let noOptions = Self(key: "<nothing>", value: .empty)
 
@@ -166,7 +164,7 @@ extension RuleConfigurationOption: Documentable {
 }
 
 /// Type of an option.
-public enum OptionType: Equatable {
+public enum OptionType: Equatable, Sendable {
     /// An irrelevant option. It will be ignored in documentation serialization.
     case empty
     /// A boolean flag.
@@ -319,7 +317,7 @@ public protocol AcceptableByConfigurationElement {
     /// - Parameters:
     ///   - value: Value from a configuration.
     ///   - ruleID: The rule's identifier in which context the configuration parsing runs.
-    init(fromAny value: Any, context ruleID: String) throws
+    init(fromAny value: Any, context ruleID: String) throws(Issue)
 
     /// Make the object an option.
     ///
@@ -336,8 +334,10 @@ public protocol AcceptableByConfigurationElement {
 
     /// Update the object.
     ///
-    /// - Parameter value: New underlying data for the object.
-    mutating func apply(_ value: Any?, ruleID: String) throws
+    /// - Parameters:
+    ///   - value: New underlying data for the object.
+    ///   - ruleID: The rule's identifier in which context the configuration parsing runs.
+    mutating func apply(_ value: Any, ruleID: String) throws(Issue)
 }
 
 /// Default implementations which are shortcuts applicable for most of the types conforming to the protocol.
@@ -346,10 +346,8 @@ public extension AcceptableByConfigurationElement {
         RuleConfigurationDescription(options: [key => asOption()])
     }
 
-    mutating func apply(_ value: Any?, ruleID: String) throws {
-        if let value {
-            self = try Self(fromAny: value, context: ruleID)
-        }
+    mutating func apply(_ value: Any, ruleID: String) throws(Issue) {
+        self = try Self(fromAny: value, context: ruleID)
     }
 }
 
@@ -417,9 +415,9 @@ public protocol InlinableOptionType: AcceptableByConfigurationElement {}
 ///    ```
 ///
 @propertyWrapper
-public struct ConfigurationElement<T: AcceptableByConfigurationElement & Equatable>: Equatable {
+public struct ConfigurationElement<T: AcceptableByConfigurationElement & Equatable & Sendable>: Equatable, Sendable {
     /// A deprecation notice.
-    public enum DeprecationNotice {
+    public enum DeprecationNotice: Sendable {
         /// Warning suggesting an alternative option.
         case suggestAlternative(ruleID: String, name: String)
     }
@@ -450,7 +448,7 @@ public struct ConfigurationElement<T: AcceptableByConfigurationElement & Equatab
     public let inline: Bool
 
     private let deprecationNotice: DeprecationNotice?
-    private let postprocessor: (inout T) -> Void
+    private let postprocessor: @Sendable (inout T) -> Void
 
     /// Default constructor.
     ///
@@ -460,10 +458,12 @@ public struct ConfigurationElement<T: AcceptableByConfigurationElement & Equatab
     ///   - deprecationNotice: An optional deprecation notice in case an option is outdated and/or has been replaced by
     ///                        an alternative.
     ///   - postprocessor: Function to be applied to the wrapped value after parsing to validate and modify it.
+    @preconcurrency
     public init(wrappedValue value: T,
                 key: String,
                 deprecationNotice: DeprecationNotice? = nil,
-                postprocessor: @escaping (inout T) -> Void = { _ in }) { // swiftlint:disable:this no_empty_block
+                postprocessor: @escaping @Sendable (inout T) -> Void = { _ in }) {
+        // swiftlint:disable:previous no_empty_block
         self.init(
             wrappedValue: value,
             key: key,
@@ -511,7 +511,8 @@ public struct ConfigurationElement<T: AcceptableByConfigurationElement & Equatab
                  key: String,
                  inline: Bool,
                  deprecationNotice: DeprecationNotice? = nil,
-                 postprocessor: @escaping (inout T) -> Void = { _ in }) { // swiftlint:disable:this no_empty_block
+                 postprocessor: @escaping @Sendable (inout T) -> Void = { _ in }) {
+        // swiftlint:disable:previous no_empty_block
         self.wrappedValue = wrappedValue
         self.key = key
         self.inline = inline
@@ -537,7 +538,7 @@ extension Optional: AcceptableByConfigurationElement where Wrapped: AcceptableBy
         self?.asOption() ?? .empty
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         self = try Wrapped(fromAny: value, context: ruleID)
     }
 }
@@ -549,9 +550,9 @@ struct Symbol: Equatable, AcceptableByConfigurationElement {
         .symbol(value)
     }
 
-    init(fromAny value: Any, context ruleID: String) throws {
+    init(fromAny value: Any, context ruleID: String) throws(Issue) {
         guard let value = value as? String else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+            throw .invalidConfiguration(ruleID: ruleID)
         }
         self.value = value
     }
@@ -562,9 +563,9 @@ extension Bool: AcceptableByConfigurationElement {
         .flag(self)
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         guard let value = value as? Self else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+            throw .invalidConfiguration(ruleID: ruleID)
         }
         self = value
     }
@@ -575,9 +576,9 @@ extension String: AcceptableByConfigurationElement {
         .string(self)
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         guard let value = value as? Self else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+            throw .invalidConfiguration(ruleID: ruleID)
         }
         self = value
     }
@@ -588,9 +589,11 @@ extension Array: AcceptableByConfigurationElement where Element: AcceptableByCon
         .list(map { $0.asOption() })
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         let values = value as? [Any] ?? [value]
-        self = try values.map { try Element(fromAny: $0, context: ruleID) }
+        self = try values.map { value throws(Issue) in
+            try Element(fromAny: value, context: ruleID)
+        }
     }
 }
 
@@ -599,7 +602,7 @@ extension Set: AcceptableByConfigurationElement where Element: AcceptableByConfi
         sorted().asOption()
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         self = Set(try [Element].init(fromAny: value, context: ruleID))
     }
 }
@@ -609,9 +612,9 @@ extension Int: AcceptableByConfigurationElement {
         .integer(self)
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         guard let value = value as? Self else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+            throw .invalidConfiguration(ruleID: ruleID)
         }
         self = value
     }
@@ -622,11 +625,14 @@ extension Double: AcceptableByConfigurationElement {
         .float(self)
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
-        guard let value = value as? Self else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
+        if let value = value as? Self {
+            self = value
+        } else if let value = value as? Int {
+            self = Double(value)
+        } else {
+            throw .invalidConfiguration(ruleID: ruleID)
         }
-        self = value
     }
 }
 
@@ -635,11 +641,11 @@ extension RegularExpression: AcceptableByConfigurationElement {
         .string(pattern)
     }
 
-    public init(fromAny value: Any, context ruleID: String) throws {
+    public init(fromAny value: Any, context ruleID: String) throws(Issue) {
         guard let value = value as? String else {
-            throw Issue.invalidConfiguration(ruleID: ruleID)
+            throw .invalidConfiguration(ruleID: ruleID)
         }
-        self = try Self(pattern: value)
+        self = try .from(pattern: value, for: ruleID)
     }
 }
 
@@ -657,14 +663,12 @@ public extension AcceptableByConfigurationElement where Self: RuleConfiguration
         return RuleConfigurationDescription(options: [key => asOption()])
     }
 
-    mutating func apply(_ value: Any?, ruleID _: String) throws {
-        if let value {
-            try apply(configuration: value)
-        }
+    mutating func apply(_ value: Any, ruleID _: String) throws(Issue) {
+        try apply(configuration: value)
     }
 
-    init(fromAny _: Any, context _: String) throws {
-        throw Issue.genericError("Do not call this initializer")
+    init(fromAny _: Any, context _: String) throws(Issue) {
+        throw .genericError("Do not call this initializer")
     }
 }
 
