@@ -1,5 +1,5 @@
 /// An identifier representing a SwiftLint rule, or all rules.
-public enum RuleIdentifier: Hashable, ExpressibleByStringLiteral {
+public enum RuleIdentifier: Hashable, ExpressibleByStringLiteral, Comparable, Sendable {
     // MARK: - Values
 
     /// Special identifier that should be treated as referring to 'all' SwiftLint rules. One helpful usecase is in
@@ -39,4 +39,10 @@ public enum RuleIdentifier: Hashable, ExpressibleByStringLiteral {
     public init(stringLiteral value: String) {
         self = Self(value)
     }
+
+    // MARK: - Comparable Conformance
+
+    public static func < (lhs: Self, rhs: Self) -> Bool {
+        lhs.stringRepresentation < rhs.stringRepresentation
+    }
 }
