@@ -27,7 +27,7 @@ public struct RuleList {
         var tmpAliases = [String: String]()
 
         for rule in rules {
-            let identifier = rule.description.identifier
+            let identifier = rule.identifier
             tmpList[identifier] = rule
             for alias in rule.description.deprecatedAliases {
                 tmpAliases[alias] = identifier
@@ -40,13 +40,14 @@ public struct RuleList {
 
     // MARK: - Internal
 
-    internal func allRulesWrapped(configurationDict: [String: Any] = [:]) throws -> [ConfigurationRuleWrapper] {
+    package func allRulesWrapped(configurationDict: [String: Any] = [:])
+            throws(RuleListError) -> [ConfigurationRuleWrapper] {
         var rules = [String: ConfigurationRuleWrapper]()
 
         // Add rules where configuration exists
         for (key, configuration) in configurationDict {
             guard let identifier = identifier(for: key), let ruleType = list[identifier] else { continue }
-            guard rules[identifier] == nil else { throw RuleListError.duplicatedConfigurations(rule: ruleType) }
+            guard rules[identifier] == nil else { throw .duplicatedConfigurations(rule: ruleType) }
             do {
                 let configuredRule = try ruleType.init(configuration: configuration)
                 let isConfigured = (configuration as? [String: Any])?.isEmpty == false
@@ -72,11 +73,11 @@ public struct RuleList {
         return Array(rules.values)
     }
 
-    internal func identifier(for alias: String) -> String? {
+    package func identifier(for alias: String) -> String? {
         aliases[alias]
     }
 
-    internal func allValidIdentifiers() -> [String] {
+    package func allValidIdentifiers() -> [String] {
         list.flatMap { _, rule -> [String] in
             rule.description.allIdentifiers
         }
