@@ -1,5 +1,6 @@
 /// A configuration parameter for rules.
-public struct RuleParameter<T: Equatable>: Equatable {
+@preconcurrency
+public struct RuleParameter<T: Equatable>: Equatable, Sendable where T: Sendable {
     /// The severity that should be assigned to the violation of this parameter's value is met.
     public let severity: ViolationSeverity
     /// The value to configure the rule.
