@@ -1,3 +1,6 @@
+import Foundation
+import SourceKittenFramework
+
 /// A value describing an instance of Swift source code that is considered invalid by a SwiftLint rule.
 public struct StyleViolation: CustomStringConvertible, Codable, Hashable {
     /// The identifier of the rule that generated this violation.
@@ -20,7 +23,14 @@ public struct StyleViolation: CustomStringConvertible, Codable, Hashable {
 
     /// A printable description for this violation.
     public var description: String {
-        XcodeReporter.generateForSingleViolation(self)
+        // {full_path_to_file}{:line}{:character}: {error,warning}: {content}
+        [
+            "\(location): ",
+            "\(severity.rawValue): ",
+            "\(ruleName) Violation: ",
+            reason,
+            " (\(ruleIdentifier))",
+        ].joined()
     }
 
     /// Creates a `StyleViolation` by specifying its properties directly.
