@@ -1,32 +1,37 @@
 import Foundation
-import SourceKittenFramework
+@preconcurrency import SourceKittenFramework
 
 /// A unit of Swift source code, either on disk or in memory.
-public final class SwiftLintFile {
+public final class SwiftLintFile: Sendable {
     /// The underlying SourceKitten file.
     public let file: File
     /// The associated unique identifier for this file.
     public let id: UUID
     /// Whether or not this is a file generated for testing purposes.
-    public private(set) var isTestFile = false
+    public let isTestFile: Bool
     /// A file is virtual if it is not backed by a filesystem path.
-    public private(set) var isVirtual = false
+    public let isVirtual: Bool
 
     /// Creates a `SwiftLintFile` with a SourceKitten `File`.
     ///
     /// - parameter file: A file from SourceKitten.
-    public init(file: File) {
+    /// - parameter isTestFile: Mark the file as being generated for testing purposes only.
+    /// - parameter isVirtual: Mark the file as virtual (in-memory).
+    public init(file: File, isTestFile: Bool = false, isVirtual: Bool = false) {
         self.file = file
         self.id = UUID()
+        self.isTestFile = isTestFile
+        self.isVirtual = isVirtual
     }
 
     /// Creates a `SwiftLintFile` by specifying its path on disk.
     /// Fails if the file does not exist.
     ///
     /// - parameter path: The path to a file on disk. Relative and absolute paths supported.
-    public convenience init?(path: String) {
+    /// - parameter isTestFile: Mark the file as being generated for testing purposes only.
+    public convenience init?(path: String, isTestFile: Bool = false) {
         guard let file = File(path: path) else { return nil }
-        self.init(file: file)
+        self.init(file: file, isTestFile: isTestFile)
     }
 
     /// Creates a `SwiftLintFile` by specifying its path on disk. Unlike the  `SwiftLintFile(path:)` initializer, this
@@ -40,9 +45,9 @@ public final class SwiftLintFile {
     /// Creates a `SwiftLintFile` that is not backed by a file on disk by specifying its contents.
     ///
     /// - parameter contents: The contents of the file.
-    public convenience init(contents: String) {
-        self.init(file: File(contents: contents))
-        isVirtual = true
+    /// - parameter isTestFile: Mark the file as being generated for testing purposes only.
+    public convenience init(contents: String, isTestFile: Bool = false) {
+        self.init(file: File(contents: contents), isTestFile: isTestFile, isVirtual: true)
     }
 
     /// The path on disk for this file.
@@ -64,11 +69,6 @@ public final class SwiftLintFile {
     public var lines: [Line] {
         file.lines
     }
-
-    /// Mark this file as used for testing purposes.
-    package func markAsTestFile() {
-        isTestFile = true
-    }
 }
 
 // MARK: - Hashable Conformance
