@@ -45,50 +45,65 @@ extension VersionComparable {
 }
 
 public extension SwiftVersion {
-    /// Swift 5.0.x - https://swift.org/download/#swift-50
+    /// Swift 5
     static let five = SwiftVersion(rawValue: "5.0.0")
-    /// Swift 5.1.x - https://swift.org/download/#swift-51
+    /// Swift 5.1
     static let fiveDotOne = SwiftVersion(rawValue: "5.1.0")
-    /// Swift 5.2.x - https://swift.org/download/#swift-52
+    /// Swift 5.2
     static let fiveDotTwo = SwiftVersion(rawValue: "5.2.0")
-    /// Swift 5.3.x - https://swift.org/download/#swift-53
+    /// Swift 5.3
     static let fiveDotThree = SwiftVersion(rawValue: "5.3.0")
-    /// Swift 5.4.x - https://swift.org/download/#swift-54
+    /// Swift 5.4
     static let fiveDotFour = SwiftVersion(rawValue: "5.4.0")
-    /// Swift 5.5.x - https://swift.org/download/#swift-55
+    /// Swift 5.5
     static let fiveDotFive = SwiftVersion(rawValue: "5.5.0")
-    /// Swift 5.6.x - https://swift.org/download/#swift-56
+    /// Swift 5.6
     static let fiveDotSix = SwiftVersion(rawValue: "5.6.0")
-    /// Swift 5.7.x - https://swift.org/download/#swift-57
+    /// Swift 5.7
     static let fiveDotSeven = SwiftVersion(rawValue: "5.7.0")
-    /// Swift 5.8.x - https://swift.org/download/#swift-58
+    /// Swift 5.8
     static let fiveDotEight = SwiftVersion(rawValue: "5.8.0")
-    /// Swift 5.9.x - https://swift.org/download/#swift-59
+    /// Swift 5.9
     static let fiveDotNine = SwiftVersion(rawValue: "5.9.0")
+    /// Swift 6
+    static let six = SwiftVersion(rawValue: "6.0.0")
+    /// Swift 6.1
+    static let sixDotOne = SwiftVersion(rawValue: "6.1.0")
+    /// Swift 6.1.1
+    static let sixDotOneDotOne = SwiftVersion(rawValue: "6.1.1")
+    /// Swift 6.1.2
+    static let sixDotOneDotTwo = SwiftVersion(rawValue: "6.1.2")
+    /// Swift 6.2
+    static let sixDotTwo = SwiftVersion(rawValue: "6.2.0")
+    /// Swift 6.2.1
+    static let sixDotTwoDotOne = SwiftVersion(rawValue: "6.2.1")
+    /// Swift 6.2.2
+    static let sixDotTwoDotTwo = SwiftVersion(rawValue: "6.2.2")
+    /// Swift 6.2.3
+    static let sixDotTwoDotThree = SwiftVersion(rawValue: "6.2.3")
+    /// Swift 6.3
+    static let sixDotThree = SwiftVersion(rawValue: "6.3.0")
 
     /// The current detected Swift compiler version, based on the currently accessible SourceKit version.
     ///
     /// - note: Override by setting the `SWIFTLINT_SWIFT_VERSION` environment variable.
     static let current: SwiftVersion = {
-        // Allow forcing the Swift version, useful in cases where SourceKit isn't available
+        // Allow forcing the Swift version, useful in cases where SourceKit isn't available.
         if let envVersion = ProcessInfo.processInfo.environment["SWIFTLINT_SWIFT_VERSION"] {
-            switch envVersion {
-            case "5":
-                return .five
-            default:
-                return .five
-            }
+            return SwiftVersion(rawValue: envVersion)
         }
-
         if !Request.disableSourceKit {
             // This request was added in Swift 5.1
             let params: SourceKitObject = ["key.request": UID("source.request.compiler_version")]
-            if let result = try? Request.customRequest(request: params).send(),
-                let major = result.versionMajor, let minor = result.versionMinor, let patch = result.versionPatch {
+            // Allow this specific SourceKit request outside of rule execution context
+            let result = CurrentRule.$allowSourceKitRequestWithoutRule.withValue(true) {
+                try? Request.customRequest(request: params).sendIfNotDisabled()
+            }
+            if let result,
+               let major = result.versionMajor, let minor = result.versionMinor, let patch = result.versionPatch {
                 return SwiftVersion(rawValue: "\(major).\(minor).\(patch)")
             }
         }
-
         return .five
     }()
 }
