@@ -2,7 +2,7 @@ import Foundation
 import SourceKittenFramework
 
 /// An executable value that can identify issues (violations) in Swift source code.
-public protocol Rule {
+public protocol Rule: Sendable {
     /// The type of the configuration used to configure this rule.
     associatedtype ConfigurationType: RuleConfiguration
 
@@ -26,6 +26,10 @@ public protocol Rule {
     init(configuration: Any) throws
 
     /// Create a description of how this rule has been configured to run.
+    ///
+    /// - parameter exclusiveOptions: A set of options that should be excluded from the description.
+    ///
+    /// - returns: A description of the rule's configuration.
     func createConfigurationDescription(exclusiveOptions: Set<String>) -> RuleConfigurationDescription
 
     /// Executes the rule on a file and returns any violations to the rule's expectations.
@@ -48,7 +52,7 @@ public protocol Rule {
     /// - parameter rule: The `rule` value to compare against.
     ///
     /// - returns: Whether or not the specified rule is equivalent to the current rule.
-    func isEqualTo(_ rule: any Rule) -> Bool
+    func isEqualTo(_ rule: some Rule) -> Bool
 
     /// Collects information for the specified file in a storage object, to be analyzed by a `CollectedLinter`.
     ///
@@ -79,17 +83,21 @@ public protocol Rule {
     ///   - ruleID: The name of a rule as used in a disable command.
     ///
     /// - Returns: A boolean value indicating whether the violation can be disabled by the given ID.
-   func canBeDisabled(violation: StyleViolation, by ruleID: RuleIdentifier) -> Bool
+    func canBeDisabled(violation: StyleViolation, by ruleID: RuleIdentifier) -> Bool
 
-   /// Checks if a the rule is enabled in a given region. A specific rule ID can be provided in case a rule supports
-   /// more than one identifier.
-   ///
-   /// - Parameters:
-   ///   - region: The region to check.
-   ///   - ruleID: Rule identifier deviating from the default rule's name.
-   ///
-   /// - Returns: A boolean value indicating whether the rule is enabled in the given region.
-   func isEnabled(in region: Region, for ruleID: String) -> Bool
+    /// Checks if a the rule is enabled in a given region. A specific rule ID can be provided in case a rule supports
+    /// more than one identifier.
+    ///
+    /// - Parameters:
+    ///   - region: The region to check.
+    ///   - ruleID: Rule identifier deviating from the default rule's name.
+    ///
+    /// - Returns: A boolean value indicating whether the rule is enabled in the given region.
+    func isEnabled(in region: Region, for ruleID: String) -> Bool
+
+    /// Prints a warning to the console once about the rule being disabled due to SourceKit being unavailable. The
+    /// default implementation does nothing. Rules that depend on SourceKit should override this appropriately.
+    func notifyRuleDisabledOnce()
 }
 
 public extension Rule {
@@ -110,7 +118,7 @@ public extension Rule {
         validate(file: file)
     }
 
-    func isEqualTo(_ rule: any Rule) -> Bool {
+    func isEqualTo(_ rule: some Rule) -> Bool {
         if let rule = rule as? Self {
             return configuration == rule.configuration
         }
@@ -144,6 +152,10 @@ public extension Rule {
     func isEnabled(in region: Region, for ruleID: String) -> Bool {
         !Self.description.allIdentifiers.contains(ruleID) || region.isRuleEnabled(self)
     }
+
+    func notifyRuleDisabledOnce() {
+        // Intentionally empty by default.
+    }
 }
 
 public extension Rule {
@@ -161,15 +173,15 @@ public protocol CorrectableRule: Rule {
     /// - parameter file:              The file for which to correct violations.
     /// - parameter compilerArguments: The compiler arguments needed to compile this file.
     ///
-    /// - returns: All corrections that were applied.
-    func correct(file: SwiftLintFile, compilerArguments: [String]) -> [Correction]
+    /// - returns: Number of corrections that were applied.
+    func correct(file: SwiftLintFile, compilerArguments: [String]) -> Int
 
     /// Attempts to correct the violations to this rule in the specified file.
     ///
     /// - parameter file: The file for which to correct violations.
     ///
-    /// - returns: All corrections that were applied.
-    func correct(file: SwiftLintFile) -> [Correction]
+    /// - returns: Number of corrections that were applied.
+    func correct(file: SwiftLintFile) -> Int
 
     /// Attempts to correct the violations to this rule in the specified file after collecting file info for all files
     /// and returns all corrections that were applied.
@@ -181,14 +193,14 @@ public protocol CorrectableRule: Rule {
     /// - parameter compilerArguments: The compiler arguments needed to compile this file.
     ///
     /// - returns: All corrections that were applied.
-    func correct(file: SwiftLintFile, using storage: RuleStorage, compilerArguments: [String]) -> [Correction]
+    func correct(file: SwiftLintFile, using storage: RuleStorage, compilerArguments: [String]) -> Int
 }
 
 public extension CorrectableRule {
-    func correct(file: SwiftLintFile, compilerArguments _: [String]) -> [Correction] {
+    func correct(file: SwiftLintFile, compilerArguments _: [String]) -> Int {
         correct(file: file)
     }
-    func correct(file: SwiftLintFile, using _: RuleStorage, compilerArguments: [String]) -> [Correction] {
+    func correct(file: SwiftLintFile, using _: RuleStorage, compilerArguments: [String]) -> Int {
         correct(file: file, compilerArguments: compilerArguments)
     }
 }
@@ -213,30 +225,55 @@ public protocol SubstitutionCorrectableRule: CorrectableRule {
 }
 
 public extension SubstitutionCorrectableRule {
-    func correct(file: SwiftLintFile) -> [Correction] {
+    func correct(file: SwiftLintFile) -> Int {
         let violatingRanges = file.ruleEnabled(violatingRanges: violationRanges(in: file), for: self)
-        guard violatingRanges.isNotEmpty else { return [] }
-
-        let description = Self.description
-        var corrections = [Correction]()
+        guard violatingRanges.isNotEmpty else {
+            return 0
+        }
+        var numberOfCorrections = 0
         var contents = file.contents
         for range in violatingRanges.sorted(by: { $0.location > $1.location }) {
             let contentsNSString = contents.bridge()
-            if let (rangeToRemove, substitution) = self.substitution(for: range, in: file) {
+            if let (rangeToRemove, substitution) = substitution(for: range, in: file) {
                 contents = contentsNSString.replacingCharacters(in: rangeToRemove, with: substitution)
-                let location = Location(file: file, characterOffset: range.location)
-                corrections.append(Correction(ruleDescription: description, location: location))
+                numberOfCorrections += 1
             }
         }
 
         file.write(contents)
-        return corrections
+        return numberOfCorrections
     }
 }
 
 /// A rule that does not need SourceKit to operate and can still operate even after SourceKit has crashed.
 public protocol SourceKitFreeRule: Rule {}
 
+/// A rule that may or may not require SourceKit depending on its configuration.
+public protocol ConditionallySourceKitFree: Rule {
+    /// Whether this rule is currently configured in a way that doesn't require SourceKit.
+    var isEffectivelySourceKitFree: Bool { get }
+}
+
+public extension Rule {
+    /// Whether this rule requires SourceKit to operate.
+    /// Returns false if the rule conforms to SourceKitFreeRule or if it conforms to
+    /// ConditionallySourceKitFree and is currently configured to not require SourceKit.
+    var requiresSourceKit: Bool {
+        // Check if rule conforms to SourceKitFreeRule
+        if self is any SourceKitFreeRule {
+            return false
+        }
+
+        // Check if rule is conditionally SourceKit-free and currently doesn't need SourceKit
+        if let conditionalRule = self as? any ConditionallySourceKitFree {
+            return !conditionalRule.isEffectivelySourceKitFree
+        }
+
+        // All other rules require SourceKit
+        return true
+    }
+}
+
 /// A rule that can operate on the post-typechecked AST using compiler arguments. Performs rules that are more like
 /// static analysis than syntactic checks.
 public protocol AnalyzerRule: OptInRule {}
@@ -249,7 +286,7 @@ public extension AnalyzerRule {
 
 /// :nodoc:
 public extension AnalyzerRule where Self: CorrectableRule {
-    func correct(file _: SwiftLintFile) -> [Correction] {
+    func correct(file _: SwiftLintFile) -> Int {
         queuedFatalError("Must call `correct(file:compilerArguments:)` for AnalyzerRule")
     }
 }
