@@ -1,5 +1,5 @@
 /// A configuration value for a rule to allow users to modify its behavior.
-public protocol RuleConfiguration: Equatable {
+public protocol RuleConfiguration: Equatable, Sendable {
     /// The type of the rule that's using this configuration.
     associatedtype Parent: Rule
 
@@ -12,7 +12,11 @@ public protocol RuleConfiguration: Equatable {
     /// - parameter configuration: The untyped configuration value to apply.
     ///
     /// - throws: Throws if the configuration is not in the expected format.
-    mutating func apply(configuration: Any) throws
+    mutating func apply(configuration: Any) throws(Issue)
+
+    /// Run a sanity check on the configuration, perform optional postprocessing steps and/or warn about potential
+    /// issues.
+    mutating func validate() throws(Issue)
 }
 
 /// A configuration for a rule that allows to configure at least the severity.
@@ -30,6 +34,11 @@ public extension SeverityBasedRuleConfiguration {
 
 public extension RuleConfiguration {
     var parameterDescription: RuleConfigurationDescription? { nil }
+
+    // swiftlint:disable:next unneeded_throws_rethrows
+    func validate() throws(Issue) {
+        // Do nothing by default.
+    }
 }
 
 public extension RuleConfiguration {
