@@ -1,5 +1,5 @@
 /// A rule configuration that allows specifying thresholds for `warning` and `error` severities.
-public struct SeverityLevelsConfiguration<Parent: Rule>: RuleConfiguration, InlinableOptionType {
+public struct SeverityLevelsConfiguration<Parent: Rule>: RuleConfiguration, InlinableOptionType, Sendable {
     /// The threshold for a violation to be a warning.
     @ConfigurationElement(key: "warning")
     public var warning = 12
@@ -27,31 +27,32 @@ public struct SeverityLevelsConfiguration<Parent: Rule>: RuleConfiguration, Inli
         return [RuleParameter(severity: .warning, value: warning)]
     }
 
-    public mutating func apply(configuration: Any) throws {
+    public mutating func apply(configuration: Any) throws(Issue) {
         if let configurationArray = [Int].array(of: configuration), configurationArray.isNotEmpty {
             warning = configurationArray[0]
             error = (configurationArray.count > 1) ? configurationArray[1] : nil
         } else if let configDict = configuration as? [String: Any?] {
-            if let warningValue = configDict[$warning.key] {
+            let warningValue = configDict[$warning.key]
+            if let warningValue {
                 if let warning = warningValue as? Int {
                     self.warning = warning
                 } else {
-                    throw Issue.invalidConfiguration(ruleID: Parent.identifier)
+                    throw .invalidConfiguration(ruleID: Parent.identifier)
                 }
             }
             if let errorValue = configDict[$error.key] {
                 if errorValue == nil {
-                    self.error = nil
+                    error = nil
                 } else if let error = errorValue as? Int {
                     self.error = error
                 } else {
-                    throw Issue.invalidConfiguration(ruleID: Parent.identifier)
+                    throw .invalidConfiguration(ruleID: Parent.identifier)
                 }
-            } else {
-                self.error = nil
+            } else if warningValue != nil {
+                error = nil
             }
         } else {
-            throw Issue.nothingApplied(ruleID: Parent.identifier)
+            throw .nothingApplied(ruleID: Parent.identifier)
         }
     }
 }
