@@ -132,6 +132,13 @@ open class DeclaredIdentifiersTrackingVisitor<Configuration: RuleConfiguration>:
         }
     }
 
+    override open func visit(_ node: FunctionDeclSyntax) -> SyntaxVisitorContinueKind {
+        if node.parent?.is(MemberBlockItemSyntax.self) != true {
+            scope.addToCurrentScope(.localVariable(name: node.name))
+        }
+        return .visitChildren
+    }
+
     // MARK: Private methods
 
     private func collectIdentifiers(from parameters: FunctionParameterListSyntax) {
@@ -165,7 +172,7 @@ open class DeclaredIdentifiersTrackingVisitor<Configuration: RuleConfiguration>:
                 pattern.as(ExpressionPatternSyntax.self)?.expression.asFunctionCall
             }
             .map(\.arguments)
-            .flatMap { $0 }
+            .flatMap(\.self)
             .compactMap { labeledExpr -> PatternExprSyntax? in
                 labeledExpr.expression.as(PatternExprSyntax.self)
             }
