@@ -13,8 +13,6 @@ extension SwiftLint {
         var compilerLogPath: String?
         @Option(help: "The path of a compilation database to use when running AnalyzerRules.")
         var compileCommands: String?
-        @Option(help: "Run only the specified rule, ignoring `only_rules`, `opt_in_rules` and `disabled_rules`.")
-        var onlyRule: String?
         @Argument(help: pathsArgumentDescription(for: .analyze))
         var paths = [String]()
 
@@ -31,6 +29,7 @@ extension SwiftLint {
                 forceExclude: common.forceExclude,
                 useExcludingByPrefix: common.useAlternativeExcluding,
                 useScriptInputFiles: common.useScriptInputFiles,
+                useScriptInputFileLists: common.useScriptInputFileLists,
                 benchmark: common.benchmark,
                 reporter: common.reporter,
                 baseline: common.baseline,
@@ -42,9 +41,10 @@ extension SwiftLint {
                 cachePath: nil,
                 ignoreCache: true,
                 enableAllRules: false,
-                onlyRule: onlyRule,
+                onlyRule: common.onlyRule,
                 autocorrect: common.fix,
                 format: common.format,
+                disableSourceKit: false,
                 compilerLogPath: compilerLogPath,
                 compileCommands: compileCommands,
                 checkForUpdates: common.checkForUpdates
