@@ -11,7 +11,7 @@ extension SwiftLint {
         @Argument(help: "The identifier of the rule to open the documentation for")
         var ruleID: String?
 
-        func run() throws {
+        func run() {
             var subPage = ""
             if let ruleID {
                 if RuleRegistry.shared.rule(forID: ruleID) == nil {
@@ -22,7 +22,6 @@ extension SwiftLint {
                 }
             }
             open(URL(string: "https://realm.github.io/SwiftLint/\(subPage)")!)
-            ExitHelper.successfullyExit()
         }
     }
 }
