@@ -19,8 +19,11 @@ extension SwiftLint {
         var noCache = false
         @Flag(help: "Run all rules, even opt-in and disabled ones, ignoring `only_rules`.")
         var enableAllRules = false
-        @Option(help: "Run only the specified rule, ignoring `only_rules`, `opt_in_rules` and `disabled_rules`.")
-        var onlyRule: String?
+        @Flag(
+            name: .customLong("disable-sourcekit"),
+            help: "Do not dynamically load SourceKit at runtime. Skip and report rules that require it."
+        )
+        var disableSourceKit = false
         @Argument(help: pathsArgumentDescription(for: .lint))
         var paths = [String]()
 
@@ -43,6 +46,7 @@ extension SwiftLint {
                 forceExclude: common.forceExclude,
                 useExcludingByPrefix: common.useAlternativeExcluding,
                 useScriptInputFiles: common.useScriptInputFiles,
+                useScriptInputFileLists: common.useScriptInputFileLists,
                 benchmark: common.benchmark,
                 reporter: common.reporter,
                 baseline: common.baseline,
@@ -54,9 +58,10 @@ extension SwiftLint {
                 cachePath: cachePath,
                 ignoreCache: noCache,
                 enableAllRules: enableAllRules,
-                onlyRule: onlyRule,
+                onlyRule: common.onlyRule,
                 autocorrect: common.fix,
                 format: common.format,
+                disableSourceKit: disableSourceKit,
                 compilerLogPath: nil,
                 compileCommands: nil,
                 checkForUpdates: common.checkForUpdates
