@@ -6,9 +6,8 @@ extension SwiftLint {
     struct Reporters: ParsableCommand {
         static let configuration = CommandConfiguration(abstract: "Display the list of reporters and their identifiers")
 
-        func run() throws {
+        func run() {
             print(TextTable(reporters: reportersList).render())
-            ExitHelper.successfullyExit()
         }
     }
 }
