@@ -1,14 +1,10 @@
 import ArgumentParser
-#if canImport(Darwin)
-import Darwin
-#elseif canImport(Glibc)
-import Glibc
-#else
-#error("Unsupported platform")
-#endif
 import Foundation
 import SwiftLintFramework
 import SwiftyTextTable
+#if os(Windows)
+import WinSDK
+#endif
 
 private typealias SortedRules = [(String, any Rule.Type)]
 
@@ -29,25 +25,21 @@ extension SwiftLint {
         @Argument(help: "The rule identifier to display description for")
         var ruleID: String?
 
-        func run() throws {
-            let configuration = Configuration(configurationFiles: [config].compactMap({ $0 }))
+        func run() throws(SwiftLintError) {
+            let configuration = Configuration(configurationFiles: [config].compactMap(\.self))
             if let ruleID {
                 guard let rule = RuleRegistry.shared.rule(forID: ruleID) else {
-                    throw SwiftLintError.usageError(description: "No rule with identifier: \(ruleID)")
+                    throw .usageError(description: "No rule with identifier: \(ruleID)")
                 }
                 printDescription(for: rule, with: configuration)
-                ExitHelper.successfullyExit()
                 return
             }
             let rules = RulesFilter(enabledRules: configuration.rules)
-                .getRules(excluding: .excludingOptions(byCommandLineOptions: rulesFilterOptions))
+                .getRules(excluding: rulesFilterOptions.excludingOptions)
                 .list
                 .sorted { $0.0 < $1.0 }
             if configOnly {
-                rules
-                    .map(\.value)
-                    .map { createInstance(of: $0, using: configuration, configure: !defaultConfig) }
-                    .forEach { printConfig(for: $0) }
+                rules.forEach { printConfig(for: createInstance(of: $0.value, using: configuration)) }
             } else {
                 let table = TextTable(
                     ruleList: rules,
@@ -57,19 +49,21 @@ extension SwiftLint {
                 )
                 print(table.render())
             }
-            ExitHelper.successfullyExit()
         }
 
         private func printDescription(for ruleType: any Rule.Type, with configuration: Configuration) {
             let description = ruleType.description
 
-            let rule = createInstance(of: ruleType, using: configuration, configure: !defaultConfig)
+            let rule = createInstance(of: ruleType, using: configuration)
             if configOnly {
                 printConfig(for: rule)
                 return
             }
 
             print("\(description.consoleDescription)")
+            if let consoleRationale = description.consoleRationale {
+                print("\nRationale:\n\n\(consoleRationale)")
+            }
             let configDescription = rule.createConfigurationDescription()
             if configDescription.hasContent {
                 print("\nConfiguration (YAML):\n")
@@ -85,7 +79,7 @@ extension SwiftLint {
             }
         }
 
-        private func printConfig(for rule: any Rule) {
+        private func printConfig(for rule: some Rule) {
             let configDescription = rule.createConfigurationDescription()
             if configDescription.hasContent {
                 print("\(type(of: rule).identifier):")
@@ -93,12 +87,10 @@ extension SwiftLint {
             }
         }
 
-        private func createInstance(of ruleType: any Rule.Type,
-                                    using config: Configuration,
-                                    configure: Bool) -> any Rule {
-            configure
-                ? config.configuredRule(forID: ruleType.identifier) ?? ruleType.init()
-                : ruleType.init()
+        private func createInstance(of ruleType: any Rule.Type, using config: Configuration) -> any Rule {
+            defaultConfig
+                ? ruleType.init()
+                : config.configuredRule(forID: ruleType.identifier) ?? ruleType.init()
         }
     }
 }
@@ -143,7 +135,7 @@ private extension TextTable {
                 configuredRule != nil ? "yes" : "no",
                 ruleType.description.kind.rawValue,
                 (rule is any AnalyzerRule) ? "yes" : "no",
-                (rule is any SourceKitFreeRule) ? "no" : "yes",
+                rule.requiresSourceKit ? "yes" : "no",
                 truncate((defaultConfig ? rule : configuredRule ?? rule).createConfigurationDescription().oneLiner()),
             ])
         }
@@ -152,6 +144,13 @@ private extension TextTable {
 
 private struct Terminal {
     static func currentWidth() -> Int {
+#if os(Windows)
+        var csbi = CONSOLE_SCREEN_BUFFER_INFO()
+        guard GetConsoleScreenBufferInfo(GetStdHandle(STD_OUTPUT_HANDLE), &csbi) else {
+            return 80
+        }
+        return Int(csbi.srWindow.Right - csbi.srWindow.Left) + 1
+#else
         var size = winsize()
 #if os(Linux)
         _ = ioctl(CInt(STDOUT_FILENO), UInt(TIOCGWINSZ), &size)
@@ -159,5 +158,6 @@ private struct Terminal {
         _ = ioctl(STDOUT_FILENO, TIOCGWINSZ, &size)
 #endif
         return Int(size.ws_col)
+#endif
     }
 }
