@@ -10,7 +10,11 @@ import SwiftLintFramework
 struct SwiftLint: AsyncParsableCommand {
     static let configuration: CommandConfiguration = {
         if let directory = ProcessInfo.processInfo.environment["BUILD_WORKSPACE_DIRECTORY"] {
-            FileManager.default.changeCurrentDirectoryPath(directory)
+            if !FileManager.default.changeCurrentDirectoryPath(directory) {
+                queuedFatalError("""
+                    Could not change current directory to \(directory) specified by BUILD_WORKSPACE_DIRECTORY.
+                    """)
+            }
         }
 
         RuleRegistry.registerAllRulesOnce()
