@@ -20,9 +20,8 @@ extension SwiftLint {
                 print(Self.value)
             }
             if checkForUpdates {
-                UpdateChecker.checkForUpdates()
+                await UpdateChecker.checkForUpdates()
             }
-            ExitHelper.successfullyExit()
         }
     }
 }
